<?php
// 设置响应头为JSON
header('Content-Type: application/json');

// 引入配置文件
require_once '../config/config.php';

// 初始化结果数组
$result = [];

// 获取供应商ID
$supplier_id = isset($_GET['supplier_id']) ? (int)$_GET['supplier_id'] : 0;

// 验证供应商ID
if ($supplier_id <= 0) {
    // 返回空结果
    echo json_encode($result);
    exit;
}

try {
    // 查询该供应商的所有订单
    $sql = "SELECT order_id, order_number, order_date, total_amount FROM purchase_orders WHERE supplier_id = ? ORDER BY order_date DESC";
    $stmt = $conn->prepare($sql);

    if ($stmt === false) {
        // 记录错误但不暴露给客户端
        error_log("准备查询供应商订单的SQL语句失败: " . $conn->error);
        echo json_encode($result);
        exit;
    }

    $stmt->bind_param("i", $supplier_id);

    if ($stmt->execute()) {
        $data = $stmt->get_result();

        if ($data) {
            while ($row = $data->fetch_assoc()) {
                $result[] = $row;
            }
        }
    } else {
        // 记录错误但不暴露给客户端
        error_log("执行查询供应商订单失败: " . $stmt->error);
    }
    $stmt->close();
} catch (Exception $e) {
    // 记录错误但不暴露给客户端
    error_log("获取供应商订单异常: " . $e->getMessage());
}

// 返回JSON格式的结果
echo json_encode($result);
exit;
