<?php
session_start();
require_once 'config/config.php';
require_once 'includes/functions.php';

// 如果用户已登录，记录登出操作
if (isset($_SESSION['user_id'])) {
    $userId = $_SESSION['user_id'];
    $username = $_SESSION['username'];

    // 记录登出操作
    $operationDetails = "用户 {$username} 退出系统";
    // 使用try-catch捕获可能的错误
    try {
        if ($conn && $conn->connect_error == null) {
            $sql = "INSERT INTO operation_logs (user_id, operation_type, operation_details) VALUES (?, ?, ?)";
            $stmt = $conn->prepare($sql);
            if ($stmt) {
                $operationType = '退出';
                $stmt->bind_param("iss", $userId, $operationType, $operationDetails);
                $stmt->execute();
                $stmt->close();
            }
        }
    } catch (Exception $e) {
        // 记录日志失败，但不影响登出流程
        error_log("登出记录失败: " . $e->getMessage());
    }
}

// 清除所有会话变量
$_SESSION = array();

// 如果使用了会话cookie，则清除会话cookie
if (ini_get("session.use_cookies")) {
    $params = session_get_cookie_params();
    setcookie(
        session_name(),
        '',
        time() - 42000,
        $params["path"],
        $params["domain"],
        $params["secure"],
        $params["httponly"]
    );
}

// 销毁会话
session_destroy();

// 重定向到登录页面
header('Location: login.php');
exit;
