<?php
// 定义系统内访问标志
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 获取操作
$action = isset($_GET['action']) ? $_GET['action'] : 'list';

// 消息提示
$message = '';
$messageType = 'info';

// 检查会话中是否有消息
if (isset($_SESSION['message']) && isset($_SESSION['message_type'])) {
    $message = $_SESSION['message'];
    $messageType = $_SESSION['message_type'];

    // 清除会话消息
    unset($_SESSION['message']);
    unset($_SESSION['message_type']);
}

// 从URL获取消息
if (empty($message) && isset($_GET['message'])) {
    $message = $_GET['message'];
    $messageType = isset($_GET['type']) ? $_GET['type'] : 'info';
}

// 设置分页和搜索条件
$page = isset($_GET['listpage']) ? max(1, intval($_GET['listpage'])) : 1;
$limit = 10;
$offset = ($page - 1) * $limit;
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$status = isset($_GET['status']) ? trim($_GET['status']) : '';
$start_date = isset($_GET['start_date']) ? trim($_GET['start_date']) : '';
$end_date = isset($_GET['end_date']) ? trim($_GET['end_date']) : '';
$delivery_method = isset($_GET['delivery_method']) ? intval($_GET['delivery_method']) : 0;

// 辅助函数：生成物流单号
function generateLogisticsNumber()
{
    $prefix = 'LG';
    $date = date('Ymd');
    $random = mt_rand(1000, 9999);
    return $prefix . $date . $random;
}

/**
 * 获取物流状态中文名称
 * @param string $status 状态码
 * @return string 中文名称
 */
function getLogisticsStatusName($status)
{
    $statusMap = [
        'pending' => '待处理',
        'processing' => '处理中',
        'shipping' => '配送中',
        'delivered' => '已送达',
        'cancelled' => '已取消',
        'exception' => '异常'
    ];
    return isset($statusMap[$status]) ? $statusMap[$status] : $status;
}

/**
 * 获取物流状态样式
 * @param string $status 状态码
 * @return string 样式类名
 */
function getLogisticsStatusBadgeClass($status)
{
    $classMap = [
        'pending' => 'warning',
        'processing' => 'info',
        'shipping' => 'primary',
        'delivered' => 'success',
        'cancelled' => 'danger',
        'exception' => 'error'
    ];
    return isset($classMap[$status]) ? $classMap[$status] : 'secondary';
}

// 处理不同操作
switch ($action) {
    case 'add':
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            // 处理添加物流订单
            $result = createLogisticsOrder($conn, $_POST);
            if ($result['success']) {
                $_SESSION['message'] = '物流订单创建成功';
                $_SESSION['message_type'] = 'success';
                header('Location: index.php?page=delivery');
                exit;
            } else {
                $message = '物流订单创建失败: ' . $result['message'];
                $messageType = 'error';
                // 保留表单数据
                $logistics = $_POST;
            }
        }

        // 获取已完成的销售出库单
        $deliverySql = "SELECT d.delivery_id, d.delivery_number, c.customer_name, d.delivery_date 
                        FROM sales_deliveries d 
                        JOIN customers c ON d.customer_id = c.customer_id 
                        LEFT JOIN logistics_orders lo ON d.delivery_id = lo.delivery_id
                        WHERE d.delivery_status = 'completed' AND lo.logistics_id IS NULL
                        ORDER BY d.delivery_date DESC";
        $deliveryResult = $conn->query($deliverySql);
        $deliveries = [];
        while ($row = $deliveryResult->fetch_assoc()) {
            $deliveries[] = $row;
        }

        // 获取配送方式
        $methodSql = "SELECT method_id, method_name, is_third_party FROM logistics_methods WHERE is_active = 1";
        $methodResult = $conn->query($methodSql);
        $methods = [];
        while ($row = $methodResult->fetch_assoc()) {
            $methods[] = $row;
        }

        // 获取物流公司
        $companySql = "SELECT company_id, company_name FROM logistics_companies WHERE is_active = 1";
        $companyResult = $conn->query($companySql);
        $companies = [];
        while ($row = $companyResult->fetch_assoc()) {
            $companies[] = $row;
        }

        include 'logistics_form.php';
        break;

    case 'edit':
        $logisticsId = isset($_GET['id']) ? intval($_GET['id']) : 0;

        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            // 处理编辑物流订单
            $_POST['logistics_id'] = $logisticsId;
            $result = updateLogisticsOrder($conn, $_POST);
            if ($result['success']) {
                $_SESSION['message'] = '物流订单更新成功';
                $_SESSION['message_type'] = 'success';
                header('Location: index.php?page=delivery');
                exit;
            } else {
                $message = '物流订单更新失败: ' . $result['message'];
                $messageType = 'error';
                // 保留表单数据
                $logistics = $_POST;
            }
        } else {
            // 获取物流订单信息
            $sql = "SELECT * FROM logistics_orders WHERE logistics_id = ?";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param("i", $logisticsId);
            $stmt->execute();
            $result = $stmt->get_result();

            if ($result && $row = $result->fetch_assoc()) {
                $logistics = $row;
            } else {
                $message = '物流订单不存在';
                $messageType = 'error';
                header('Location: index.php?page=delivery');
                exit;
            }
        }

        // 获取配送方式
        $methodSql = "SELECT method_id, method_name, is_third_party FROM logistics_methods WHERE is_active = 1";
        $methodResult = $conn->query($methodSql);
        $methods = [];
        while ($row = $methodResult->fetch_assoc()) {
            $methods[] = $row;
        }

        // 获取物流公司
        $companySql = "SELECT company_id, company_name FROM logistics_companies WHERE is_active = 1";
        $companyResult = $conn->query($companySql);
        $companies = [];
        while ($row = $companyResult->fetch_assoc()) {
            $companies[] = $row;
        }

        include 'logistics_form.php';
        break;

    case 'view':
        $logisticsId = isset($_GET['id']) ? intval($_GET['id']) : 0;

        // 获取物流订单详情
        $sql = "SELECT lo.*, c.customer_name, lm.method_name, lc.company_name,
                sd.delivery_number, u.username as created_by_name
                FROM logistics_orders lo
                JOIN customers c ON lo.customer_id = c.customer_id
                JOIN logistics_methods lm ON lo.method_id = lm.method_id
                JOIN sales_deliveries sd ON lo.delivery_id = sd.delivery_id
                LEFT JOIN logistics_companies lc ON lo.company_id = lc.company_id
                LEFT JOIN users u ON lo.created_by = u.user_id
                WHERE lo.logistics_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $logisticsId);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result && $row = $result->fetch_assoc()) {
            $logistics = $row;

            // 获取物流跟踪记录
            $trackingSql = "SELECT * FROM logistics_tracking 
                            WHERE logistics_id = ? 
                            ORDER BY tracking_time DESC";
            $trackingStmt = $conn->prepare($trackingSql);
            $trackingStmt->bind_param("i", $logisticsId);
            $trackingStmt->execute();
            $trackingResult = $trackingStmt->get_result();

            $trackingRecords = [];
            while ($trackingRow = $trackingResult->fetch_assoc()) {
                $trackingRecords[] = $trackingRow;
            }

            include 'logistics_view.php';
        } else {
            $message = '物流订单不存在';
            $messageType = 'error';
            header('Location: index.php?page=delivery');
            exit;
        }
        break;

    case 'update_status':
        $logisticsId = isset($_GET['id']) ? intval($_GET['id']) : 0;
        $status = isset($_GET['status']) ? $_GET['status'] : '';

        $validStatuses = ['pending', 'processing', 'shipping', 'delivered', 'cancelled', 'exception'];
        if (!in_array($status, $validStatuses)) {
            $_SESSION['message'] = '无效的物流状态';
            $_SESSION['message_type'] = 'error';
            header('Location: index.php?page=delivery');
            exit;
        }

        // 更新物流状态
        $sql = "UPDATE logistics_orders SET logistics_status = ? WHERE logistics_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("si", $status, $logisticsId);

        if ($stmt->execute()) {
            // 添加物流跟踪记录
            $trackingStatus = $status;
            $description = '系统自动更新状态为' . getLogisticsStatusName($status);
            $operator = isset($_SESSION['full_name']) ? $_SESSION['full_name'] : '系统';

            $trackingSql = "INSERT INTO logistics_tracking 
                           (logistics_id, tracking_time, tracking_status, tracking_description, operator)
                           VALUES (?, NOW(), ?, ?, ?)";
            $trackingStmt = $conn->prepare($trackingSql);
            $trackingStmt->bind_param("isss", $logisticsId, $trackingStatus, $description, $operator);
            $trackingStmt->execute();

            // 如果状态是delivered，更新实际送达时间
            if ($status === 'delivered') {
                $updateSql = "UPDATE logistics_orders SET actual_delivery_time = NOW() WHERE logistics_id = ?";
                $updateStmt = $conn->prepare($updateSql);
                $updateStmt->bind_param("i", $logisticsId);
                $updateStmt->execute();
            }

            $_SESSION['message'] = '物流状态更新成功';
            $_SESSION['message_type'] = 'success';
        } else {
            $_SESSION['message'] = '物流状态更新失败: ' . $stmt->error;
            $_SESSION['message_type'] = 'error';
        }

        header('Location: index.php?page=delivery');
        exit;
        break;

    case 'add_tracking':
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            $logisticsId = isset($_POST['logistics_id']) ? intval($_POST['logistics_id']) : 0;
            $trackingStatus = isset($_POST['tracking_status']) ? $_POST['tracking_status'] : '';
            $description = isset($_POST['description']) ? $_POST['description'] : '';
            $location = isset($_POST['location']) ? $_POST['location'] : '';
            $operator = isset($_SESSION['full_name']) ? $_SESSION['full_name'] : '系统';
            $isException = isset($_POST['is_exception']) ? 1 : 0;

            // 添加物流跟踪记录
            $sql = "INSERT INTO logistics_tracking 
                   (logistics_id, tracking_time, tracking_location, tracking_status, tracking_description, operator, is_exception)
                   VALUES (?, NOW(), ?, ?, ?, ?, ?)";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param("issssi", $logisticsId, $location, $trackingStatus, $description, $operator, $isException);

            if ($stmt->execute()) {
                // 如果是异常状态，更新物流订单状态
                if ($isException) {
                    $updateSql = "UPDATE logistics_orders SET logistics_status = 'exception' WHERE logistics_id = ?";
                    $updateStmt = $conn->prepare($updateSql);
                    $updateStmt->bind_param("i", $logisticsId);
                    $updateStmt->execute();
                }

                $_SESSION['message'] = '物流跟踪记录添加成功';
                $_SESSION['message_type'] = 'success';
            } else {
                $_SESSION['message'] = '物流跟踪记录添加失败: ' . $stmt->error;
                $_SESSION['message_type'] = 'error';
            }

            header('Location: index.php?page=delivery&action=view&id=' . $logisticsId);
            exit;
        }
        break;

    case 'delete':
        $logisticsId = isset($_GET['id']) ? intval($_GET['id']) : 0;

        // 检查物流订单是否存在以及其状态
        $checkSql = "SELECT logistics_status FROM logistics_orders WHERE logistics_id = ?";
        $checkStmt = $conn->prepare($checkSql);
        $checkStmt->bind_param("i", $logisticsId);
        $checkStmt->execute();
        $result = $checkStmt->get_result();

        if ($result && $row = $result->fetch_assoc()) {
            if ($row['logistics_status'] === 'delivered' || $row['logistics_status'] === 'shipping') {
                $_SESSION['message'] = '无法删除已配送或已送达的物流订单';
                $_SESSION['message_type'] = 'error';
                header('Location: index.php?page=delivery');
                exit;
            }

            // 开始事务
            $conn->begin_transaction();

            try {
                // 先删除物流跟踪记录
                $deleteSql = "DELETE FROM logistics_tracking WHERE logistics_id = ?";
                $deleteStmt = $conn->prepare($deleteSql);
                $deleteStmt->bind_param("i", $logisticsId);
                $deleteStmt->execute();

                // 再删除配送路线详情中的记录
                $deleteRouteSql = "DELETE FROM delivery_route_details WHERE logistics_id = ?";
                $deleteRouteStmt = $conn->prepare($deleteRouteSql);
                $deleteRouteStmt->bind_param("i", $logisticsId);
                $deleteRouteStmt->execute();

                // 最后删除物流订单
                $deleteOrderSql = "DELETE FROM logistics_orders WHERE logistics_id = ?";
                $deleteOrderStmt = $conn->prepare($deleteOrderSql);
                $deleteOrderStmt->bind_param("i", $logisticsId);
                $deleteOrderStmt->execute();

                $conn->commit();

                $_SESSION['message'] = '物流订单删除成功';
                $_SESSION['message_type'] = 'success';
            } catch (Exception $e) {
                $conn->rollback();
                $_SESSION['message'] = '物流订单删除失败: ' . $e->getMessage();
                $_SESSION['message_type'] = 'error';
            }
        } else {
            $_SESSION['message'] = '物流订单不存在';
            $_SESSION['message_type'] = 'error';
        }

        header('Location: index.php?page=delivery');
        exit;
        break;

    case 'list':
    default:
        // 构建查询条件
        $where = [];
        $params = [];
        $types = '';

        if (!empty($search)) {
            $where[] = "(lo.logistics_number LIKE ? OR c.customer_name LIKE ? OR lo.receiver_name LIKE ? OR lo.receiver_phone LIKE ?)";
            $searchParam = "%$search%";
            $params[] = $searchParam;
            $params[] = $searchParam;
            $params[] = $searchParam;
            $params[] = $searchParam;
            $types .= 'ssss';
        }

        if (!empty($status)) {
            $where[] = "lo.logistics_status = ?";
            $params[] = $status;
            $types .= 's';
        }

        if (!empty($start_date)) {
            $where[] = "DATE(lo.created_at) >= ?";
            $params[] = $start_date;
            $types .= 's';
        }

        if (!empty($end_date)) {
            $where[] = "DATE(lo.created_at) <= ?";
            $params[] = $end_date;
            $types .= 's';
        }

        if (!empty($delivery_method)) {
            $where[] = "lo.method_id = ?";
            $params[] = $delivery_method;
            $types .= 'i';
        }

        $whereClause = empty($where) ? "" : "WHERE " . implode(" AND ", $where);

        // 查询物流订单总数
        $countSql = "SELECT COUNT(*) AS total 
                     FROM logistics_orders lo
                     JOIN customers c ON lo.customer_id = c.customer_id
                     $whereClause";

        if (!empty($params)) {
            $countStmt = $conn->prepare($countSql);
            $countStmt->bind_param($types, ...$params);
            $countStmt->execute();
            $countResult = $countStmt->get_result();
            $totalRecords = $countResult->fetch_assoc()['total'];
        } else {
            $countResult = $conn->query($countSql);
            $totalRecords = $countResult->fetch_assoc()['total'];
        }

        $totalPages = ceil($totalRecords / $limit);

        // 查询物流订单列表
        $sql = "SELECT lo.*, c.customer_name, lm.method_name, lc.company_name,
                sd.delivery_number
                FROM logistics_orders lo
                JOIN customers c ON lo.customer_id = c.customer_id
                JOIN logistics_methods lm ON lo.method_id = lm.method_id
                JOIN sales_deliveries sd ON lo.delivery_id = sd.delivery_id
                LEFT JOIN logistics_companies lc ON lo.company_id = lc.company_id
                $whereClause
                ORDER BY lo.created_at DESC
                LIMIT ?, ?";

        $params[] = $offset;
        $params[] = $limit;
        $types .= 'ii';

        $stmt = $conn->prepare($sql);
        if (!empty($params)) {
            $stmt->bind_param($types, ...$params);
        }
        $stmt->execute();
        $result = $stmt->get_result();

        $logisticsList = [];
        while ($row = $result->fetch_assoc()) {
            $logisticsList[] = $row;
        }

        // 获取配送方式列表（用于过滤）
        $methodSql = "SELECT method_id, method_name FROM logistics_methods WHERE is_active = 1";
        $methodResult = $conn->query($methodSql);
        $methods = [];
        while ($row = $methodResult->fetch_assoc()) {
            $methods[] = $row;
        }

        // 显示物流订单列表页面
        include 'logistics_list.php';
        break;
}

/**
 * 创建物流订单
 * @param mysqli $conn 数据库连接
 * @param array $params 表单数据
 * @return array 操作结果
 */
function createLogisticsOrder($conn, $params)
{
    try {
        $conn->begin_transaction();

        // 获取参数
        $deliveryId = intval($params['delivery_id']);
        $methodId = intval($params['method_id']);
        $companyId = !empty($params['company_id']) ? intval($params['company_id']) : null;
        $trackingNumber = !empty($params['tracking_number']) ? trim($params['tracking_number']) : null;
        $logisticsNumber = generateLogisticsNumber();
        $shippingAddress = trim($params['shipping_address']);
        $receiverName = trim($params['receiver_name']);
        $receiverPhone = trim($params['receiver_phone']);
        $estimatedDeliveryTime = !empty($params['estimated_delivery_time']) ? $params['estimated_delivery_time'] : null;
        $shippingCost = !empty($params['shipping_cost']) ? floatval($params['shipping_cost']) : 0;
        $weight = !empty($params['weight']) ? floatval($params['weight']) : null;
        $volume = !empty($params['volume']) ? floatval($params['volume']) : null;
        $remark = !empty($params['remark']) ? trim($params['remark']) : null;
        $status = 'pending';
        $createdBy = isset($_SESSION['user_id']) ? intval($_SESSION['user_id']) : 1;

        // 获取销售出库单相关信息
        $deliverySql = "SELECT customer_id FROM sales_deliveries WHERE delivery_id = ?";
        $deliveryStmt = $conn->prepare($deliverySql);
        $deliveryStmt->bind_param("i", $deliveryId);
        $deliveryStmt->execute();
        $deliveryResult = $deliveryStmt->get_result();
        $deliveryData = $deliveryResult->fetch_assoc();

        if (!$deliveryData) {
            throw new Exception("销售出库单不存在");
        }

        $customerId = $deliveryData['customer_id'];

        // 准备SQL和绑定参数
        $sql = "INSERT INTO logistics_orders (
                    logistics_number, delivery_id, method_id, company_id, tracking_number,
                    customer_id, shipping_address, receiver_name, receiver_phone,
                    logistics_status, estimated_delivery_time, shipping_cost, weight, volume,
                    remark, created_by, created_at
                ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, NOW())";

        $stmt = $conn->prepare($sql);
        if (!$stmt) {
            throw new Exception("准备物流订单SQL失败: " . $conn->error);
        }

        // 完全重写绑定参数部分，确保类型字符串与参数数量匹配
        // 字符串长度：16，参数数量：16
        $types = "siiisisssssdddsi";
        $stmt->bind_param(
            $types,
            $logisticsNumber,
            $deliveryId,
            $methodId,
            $companyId,
            $trackingNumber,
            $customerId,
            $shippingAddress,
            $receiverName,
            $receiverPhone,
            $status,
            $estimatedDeliveryTime,
            $shippingCost,
            $weight,
            $volume,
            $remark,
            $createdBy
        );

        if (!$stmt->execute()) {
            throw new Exception("执行创建物流订单SQL失败: " . $stmt->error);
        }

        $logisticsId = $stmt->insert_id;

        // 添加初始物流跟踪记录
        $trackingSql = "INSERT INTO logistics_tracking 
                       (logistics_id, tracking_time, tracking_status, tracking_description, operator)
                       VALUES (?, NOW(), ?, ?, ?)";
        $trackingStmt = $conn->prepare($trackingSql);
        $trackingDescription = "订单已创建，等待处理";
        $operator = isset($_SESSION['full_name']) ? $_SESSION['full_name'] : '系统';

        $trackingStmt->bind_param("isss", $logisticsId, $status, $trackingDescription, $operator);
        if (!$trackingStmt->execute()) {
            throw new Exception("添加物流跟踪记录失败: " . $trackingStmt->error);
        }

        $conn->commit();
        return ['success' => true, 'id' => $logisticsId];
    } catch (Exception $e) {
        $conn->rollback();
        return ['success' => false, 'message' => $e->getMessage()];
    }
}

/**
 * 更新物流订单
 * @param mysqli $conn 数据库连接
 * @param array $params 表单数据
 * @return array 操作结果
 */
function updateLogisticsOrder($conn, $params)
{
    try {
        $logisticsId = intval($params['logistics_id']);
        $methodId = intval($params['method_id']);
        $companyId = !empty($params['company_id']) ? intval($params['company_id']) : null;
        $trackingNumber = !empty($params['tracking_number']) ? trim($params['tracking_number']) : null;
        $shippingAddress = trim($params['shipping_address']);
        $receiverName = trim($params['receiver_name']);
        $receiverPhone = trim($params['receiver_phone']);
        $status = trim($params['logistics_status']);
        $estimatedDeliveryTime = !empty($params['estimated_delivery_time']) ? $params['estimated_delivery_time'] : null;
        $actualDeliveryTime = !empty($params['actual_delivery_time']) ? $params['actual_delivery_time'] : null;
        $shippingCost = !empty($params['shipping_cost']) ? floatval($params['shipping_cost']) : 0;
        $weight = !empty($params['weight']) ? floatval($params['weight']) : null;
        $volume = !empty($params['volume']) ? floatval($params['volume']) : null;
        $remark = !empty($params['remark']) ? trim($params['remark']) : null;

        // 获取当前物流状态
        $currentStatusSql = "SELECT logistics_status FROM logistics_orders WHERE logistics_id = ?";
        $currentStatusStmt = $conn->prepare($currentStatusSql);
        $currentStatusStmt->bind_param("i", $logisticsId);
        $currentStatusStmt->execute();
        $currentStatusResult = $currentStatusStmt->get_result();
        $currentStatus = $currentStatusResult->fetch_assoc()['logistics_status'];

        // 更新物流订单
        $sql = "UPDATE logistics_orders SET
                method_id = ?,
                company_id = ?,
                tracking_number = ?,
                shipping_address = ?,
                receiver_name = ?,
                receiver_phone = ?,
                logistics_status = ?,
                estimated_delivery_time = ?,
                actual_delivery_time = ?,
                shipping_cost = ?,
                weight = ?,
                volume = ?,
                remark = ?,
                updated_at = NOW()
                WHERE logistics_id = ?";

        $stmt = $conn->prepare($sql);
        if (!$stmt) {
            throw new Exception("准备更新物流订单SQL失败: " . $conn->error);
        }

        // 修复参数绑定问题，确保类型字符串的长度与参数数量一致
        $types = "iisssssssddsii";
        $stmt->bind_param(
            $types,
            $methodId,
            $companyId,
            $trackingNumber,
            $shippingAddress,
            $receiverName,
            $receiverPhone,
            $status,
            $estimatedDeliveryTime,
            $actualDeliveryTime,
            $shippingCost,
            $weight,
            $volume,
            $remark,
            $logisticsId
        );

        if (!$stmt->execute()) {
            throw new Exception("执行更新物流订单SQL失败: " . $stmt->error);
        }

        // 如果状态有变化，添加物流跟踪记录
        if ($currentStatus !== $status) {
            $trackingSql = "INSERT INTO logistics_tracking 
                           (logistics_id, tracking_time, tracking_status, tracking_description, operator)
                           VALUES (?, NOW(), ?, ?, ?)";
            $trackingStmt = $conn->prepare($trackingSql);
            $trackingDescription = "状态从" . getLogisticsStatusName($currentStatus) . "变更为" . getLogisticsStatusName($status);
            $operator = isset($_SESSION['full_name']) ? $_SESSION['full_name'] : '系统';

            $trackingStmt->bind_param("isss", $logisticsId, $status, $trackingDescription, $operator);
            $trackingStmt->execute();
        }

        return ['success' => true];
    } catch (Exception $e) {
        return ['success' => false, 'message' => $e->getMessage()];
    }
}
