<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 处理删除操作
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $batch_id = (int)$_GET['id'];

    try {
        // 检查批次是否存在
        $sql = "SELECT batch_id FROM product_batches WHERE batch_id = ?";
        $stmt = $conn->prepare($sql);
        if ($stmt) {
            $stmt->bind_param("i", $batch_id);
            $stmt->execute();
            $result = $stmt->get_result();

            if ($result->num_rows > 0) {
                // 删除批次
                $deleteSql = "DELETE FROM product_batches WHERE batch_id = ?";
                $deleteStmt = $conn->prepare($deleteSql);
                if ($deleteStmt) {
                    $deleteStmt->bind_param("i", $batch_id);
                    if ($deleteStmt->execute()) {
                        // 记录操作日志
                        $operationDetails = "删除商品批次 ID: {$batch_id}";
                        log_operation($_SESSION['user_id'], '删除批次', $operationDetails);

                        header('Location: index.php?page=batch&message=删除成功&type=success');
                    } else {
                        throw new Exception("删除批次失败: " . $deleteStmt->error);
                    }
                    $deleteStmt->close();
                }
            } else {
                throw new Exception("批次不存在");
            }
            $stmt->close();
        }
    } catch (Exception $e) {
        header('Location: index.php?page=batch&message=' . urlencode($e->getMessage()) . '&type=error');
    }
    exit;
}

// 处理添加/编辑表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $batch_id = isset($_POST['batch_id']) ? (int)$_POST['batch_id'] : 0;
    $product_id = (int)$_POST['product_id'];
    $batch_number = sanitize($_POST['batch_number']);
    $production_date = sanitize($_POST['production_date']);
    $expiration_date = sanitize($_POST['expiration_date']);

    try {
        // 验证必填字段
        if (empty($product_id) || empty($batch_number) || empty($production_date) || empty($expiration_date)) {
            throw new Exception("请填写所有必填字段");
        }

        // 验证日期
        if (strtotime($production_date) > strtotime($expiration_date)) {
            throw new Exception("生产日期不能晚于到期日期");
        }

        // 检查商品是否存在
        $checkSql = "SELECT product_id FROM products WHERE product_id = ?";
        $checkStmt = $conn->prepare($checkSql);
        if ($checkStmt) {
            $checkStmt->bind_param("i", $product_id);
            $checkStmt->execute();
            if ($checkStmt->get_result()->num_rows == 0) {
                throw new Exception("选择的商品不存在");
            }
            $checkStmt->close();
        }

        if ($batch_id > 0) {
            // 更新批次
            $sql = "UPDATE product_batches SET product_id = ?, batch_number = ?, production_date = ?, expiration_date = ? WHERE batch_id = ?";
            $stmt = $conn->prepare($sql);
            if ($stmt) {
                $stmt->bind_param("isssi", $product_id, $batch_number, $production_date, $expiration_date, $batch_id);
                if ($stmt->execute()) {
                    // 记录操作日志
                    $operationDetails = "更新商品批次 ID: {$batch_id}";
                    log_operation($_SESSION['user_id'], '更新批次', $operationDetails);

                    header('Location: index.php?page=batch&message=更新成功&type=success');
                } else {
                    throw new Exception("更新批次失败: " . $stmt->error);
                }
                $stmt->close();
            }
        } else {
            // 添加新批次
            $sql = "INSERT INTO product_batches (product_id, batch_number, production_date, expiration_date) VALUES (?, ?, ?, ?)";
            $stmt = $conn->prepare($sql);
            if ($stmt) {
                $stmt->bind_param("isss", $product_id, $batch_number, $production_date, $expiration_date);
                if ($stmt->execute()) {
                    // 记录操作日志
                    $operationDetails = "添加商品批次: {$batch_number}";
                    log_operation($_SESSION['user_id'], '添加批次', $operationDetails);

                    header('Location: index.php?page=batch&message=添加成功&type=success');
                } else {
                    throw new Exception("添加批次失败: " . $stmt->error);
                }
                $stmt->close();
            }
        }
    } catch (Exception $e) {
        $error = $e->getMessage();
    }
}

// 获取当前操作
$action = isset($_GET['action']) ? $_GET['action'] : 'list';

// 获取消息
$message = isset($_GET['message']) ? $_GET['message'] : '';
$messageType = isset($_GET['type']) ? $_GET['type'] : '';

// 如果是编辑或查看操作，获取批次信息
$batch = null;
if (($action == 'edit' || $action == 'view') && isset($_GET['id'])) {
    $batch_id = (int)$_GET['id'];
    $sql = "SELECT b.*, p.product_name, p.barcode 
            FROM product_batches b 
            JOIN products p ON b.product_id = p.product_id 
            WHERE b.batch_id = ?";
    $stmt = $conn->prepare($sql);
    if ($stmt) {
        $stmt->bind_param("i", $batch_id);
        $stmt->execute();
        $result = $stmt->get_result();
        if ($result->num_rows > 0) {
            $batch = $result->fetch_assoc();
        }
        $stmt->close();
    }
}

// 获取所有商品列表
$products = [];
$sql = "SELECT product_id, product_name, barcode FROM products ORDER BY product_name";
$result = $conn->query($sql);
if ($result) {
    while ($row = $result->fetch_assoc()) {
        $products[] = $row;
    }
}

// 如果是列表页，获取批次列表
$batches = [];
if ($action == 'list') {
    // 构建查询条件
    $where = [];
    $params = [];
    $types = '';

    // 商品筛选
    if (isset($_GET['product_id']) && !empty($_GET['product_id'])) {
        $where[] = "b.product_id = ?";
        $params[] = (int)$_GET['product_id'];
        $types .= 'i';
    }

    // 批次号筛选
    if (isset($_GET['batch_number']) && !empty($_GET['batch_number'])) {
        $where[] = "b.batch_number LIKE ?";
        $params[] = "%" . sanitize($_GET['batch_number']) . "%";
        $types .= 's';
    }

    // 日期范围筛选
    if (isset($_GET['date_from']) && !empty($_GET['date_from'])) {
        $where[] = "b.production_date >= ?";
        $params[] = sanitize($_GET['date_from']);
        $types .= 's';
    }
    if (isset($_GET['date_to']) && !empty($_GET['date_to'])) {
        $where[] = "b.production_date <= ?";
        $params[] = sanitize($_GET['date_to']);
        $types .= 's';
    }

    // 构建WHERE子句
    $whereStr = !empty($where) ? "WHERE " . implode(" AND ", $where) : "";

    // 查询批次列表
    $sql = "SELECT b.*, p.product_name, p.barcode 
            FROM product_batches b 
            JOIN products p ON b.product_id = p.product_id 
            $whereStr 
            ORDER BY b.production_date DESC";

    $stmt = $conn->prepare($sql);
    if ($stmt) {
        if (!empty($params)) {
            $stmt->bind_param($types, ...$params);
        }
        $stmt->execute();
        $result = $stmt->get_result();
        while ($row = $result->fetch_assoc()) {
            // 计算剩余天数
            $expiration_date = strtotime($row['expiration_date']);
            $today = strtotime('today');
            $days_left = floor(($expiration_date - $today) / (24 * 60 * 60));
            $row['days_left'] = $days_left;
            $row['is_expiring'] = $days_left <= 30 && $days_left > 0;
            $row['is_expired'] = $days_left <= 0;

            $batches[] = $row;
        }
        $stmt->close();
    }
}
?>

<!-- 显示消息 -->
<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<!-- jQuery库必须在Select2之前引入 -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<!-- 引入Select2库 -->
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>

<!-- 添加/编辑表单 -->
<?php if ($action == 'add' || $action == 'edit'): ?>
    <div class="form-container">
        <h3><?php echo $action == 'add' ? '添加批次' : '编辑批次'; ?></h3>
        <form method="post" action="">
            <?php if ($action == 'edit' && $batch): ?>
                <input type="hidden" name="batch_id" value="<?php echo $batch['batch_id']; ?>">
            <?php endif; ?>

            <div class="form-group">
                <label for="product_id">商品 <span class="required">*</span></label>
                <select name="product_id" id="product_id" class="select2-product" required>
                    <option value="">请选择商品</option>
                    <?php foreach ($products as $product): ?>
                        <option value="<?php echo $product['product_id']; ?>"
                            <?php echo ($action == 'edit' && $batch && $batch['product_id'] == $product['product_id']) ? 'selected' : ''; ?>>
                            <?php echo $product['product_name'] . ' (' . $product['barcode'] . ')'; ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="form-group">
                <label for="batch_number">批次号 <span class="required">*</span></label>
                <input type="text" name="batch_number" id="batch_number" required
                    value="<?php echo $action == 'edit' && $batch ? $batch['batch_number'] : ''; ?>">
            </div>

            <div class="form-group">
                <label for="production_date">生产日期 <span class="required">*</span></label>
                <input type="date" name="production_date" id="production_date" required
                    value="<?php echo $action == 'edit' && $batch ? $batch['production_date'] : ''; ?>">
            </div>

            <div class="form-group">
                <label for="expiration_date">到期日期 <span class="required">*</span></label>
                <input type="date" name="expiration_date" id="expiration_date" required
                    value="<?php echo $action == 'edit' && $batch ? $batch['expiration_date'] : ''; ?>">
            </div>

            <div class="form-actions">
                <button type="submit" class="btn btn-primary">保存</button>
                <a href="index.php?page=batch" class="btn btn-secondary">返回</a>
            </div>
        </form>
    </div>

    <!-- 查看详情 -->
<?php elseif ($action == 'view' && $batch): ?>
    <div class="detail-container">
        <h3>批次详情</h3>
        <div class="detail-content">
            <div class="detail-group">
                <label>商品名称</label>
                <span><?php echo $batch['product_name']; ?></span>
            </div>
            <div class="detail-group">
                <label>商品条码</label>
                <span><?php echo $batch['barcode']; ?></span>
            </div>
            <div class="detail-group">
                <label>批次号</label>
                <span><?php echo $batch['batch_number']; ?></span>
            </div>
            <div class="detail-group">
                <label>生产日期</label>
                <span><?php echo $batch['production_date']; ?></span>
            </div>
            <div class="detail-group">
                <label>到期日期</label>
                <span><?php echo $batch['expiration_date']; ?></span>
            </div>
            <?php
            $expiration_date = strtotime($batch['expiration_date']);
            $today = strtotime('today');
            $days_left = floor(($expiration_date - $today) / (24 * 60 * 60));
            ?>
            <div class="detail-group">
                <label>剩余天数</label>
                <span class="<?php echo $days_left <= 0 ? 'text-danger' : ($days_left <= 30 ? 'text-warning' : ''); ?>">
                    <?php echo $days_left; ?> 天
                </span>
            </div>
        </div>
        <div class="detail-actions">
            <a href="index.php?page=batch&action=edit&id=<?php echo $batch['batch_id']; ?>" class="btn btn-primary">编辑</a>
            <a href="index.php?page=batch" class="btn btn-secondary">返回</a>
        </div>
    </div>

    <!-- 批次列表 -->
<?php else: ?>
    <div class="module-tools">
        <div class="tool-left">
            <a href="index.php?page=batch&action=add" class="btn btn-primary">添加批次</a>
        </div>
        <div class="tool-right">
            <form action="" method="get" class="search-form">
                <input type="hidden" name="page" value="batch">

                <div class="search-group">
                    <select name="product_id" class="select2-product">
                        <option value="">-- 所有商品 --</option>
                        <?php foreach ($products as $product): ?>
                            <option value="<?php echo $product['product_id']; ?>"
                                <?php echo isset($_GET['product_id']) && $_GET['product_id'] == $product['product_id'] ? 'selected' : ''; ?>>
                                <?php echo $product['product_name']; ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="search-group">
                    <input type="text" name="batch_number" placeholder="批次号"
                        value="<?php echo isset($_GET['batch_number']) ? htmlspecialchars($_GET['batch_number']) : ''; ?>"
                        class="search-input">
                </div>

                <div class="search-group">
                    <input type="date" name="date_from" placeholder="开始日期"
                        value="<?php echo isset($_GET['date_from']) ? htmlspecialchars($_GET['date_from']) : ''; ?>"
                        class="search-input date">
                    <span>至</span>
                    <input type="date" name="date_to" placeholder="结束日期"
                        value="<?php echo isset($_GET['date_to']) ? htmlspecialchars($_GET['date_to']) : ''; ?>"
                        class="search-input date">
                </div>

                <button type="submit" class="btn btn-secondary">搜索</button>
                <a href="index.php?page=batch" class="btn btn-secondary">重置</a>
            </form>
        </div>
    </div>

    <div class="data-wrapper">
        <table class="data-table">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>商品名称</th>
                    <th>批次号</th>
                    <th>生产日期</th>
                    <th>到期日期</th>
                    <th>剩余天数</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php if (count($batches) > 0): ?>
                    <?php foreach ($batches as $batch): ?>
                        <tr>
                            <td><?php echo $batch['batch_id']; ?></td>
                            <td><?php echo $batch['product_name']; ?></td>
                            <td><?php echo $batch['batch_number']; ?></td>
                            <td><?php echo $batch['production_date']; ?></td>
                            <td><?php echo $batch['expiration_date']; ?></td>
                            <td class="<?php echo $batch['is_expired'] ? 'text-danger' : ($batch['is_expiring'] ? 'text-warning' : ''); ?>">
                                <?php echo $batch['days_left']; ?> 天
                            </td>
                            <td class="actions">
                                <a href="index.php?page=batch&action=view&id=<?php echo $batch['batch_id']; ?>" class="btn btn-secondary btn-sm">查看</a>
                                <a href="index.php?page=batch&action=edit&id=<?php echo $batch['batch_id']; ?>" class="btn btn-primary btn-sm">编辑</a>
                                <a href="index.php?page=batch&action=delete&id=<?php echo $batch['batch_id']; ?>"
                                    class="btn btn-danger btn-sm"
                                    onclick="return confirm('确定要删除此批次吗？')">删除</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="7" class="text-center">暂无批次数据</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>
<?php endif; ?>

<style>
    /* 批次管理模块样式 */
    .form-container,
    .detail-container {
        max-width: 800px;
        margin: 0 auto;
        padding: 20px;
        background: #fff;
        border-radius: 5px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .form-container h3,
    .detail-container h3 {
        margin-bottom: 20px;
        padding-bottom: 10px;
        border-bottom: 1px solid #eee;
    }

    .form-group {
        margin-bottom: 15px;
    }

    .form-group label {
        display: block;
        margin-bottom: 5px;
        font-weight: bold;
    }

    .form-group input[type="text"],
    .form-group input[type="date"],
    .form-group select {
        width: 100%;
        padding: 8px;
        border: 1px solid #ddd;
        border-radius: 4px;
    }

    .form-actions {
        margin-top: 20px;
        text-align: right;
    }

    .form-actions .btn {
        margin-left: 10px;
    }

    .detail-content {
        display: grid;
        grid-template-columns: repeat(2, 1fr);
        gap: 20px;
        margin-bottom: 20px;
    }

    .detail-group {
        padding: 15px;
        background: #f9f9f9;
        border-radius: 4px;
    }

    .detail-group label {
        display: block;
        margin-bottom: 5px;
        color: #666;
    }

    .detail-group span {
        font-size: 16px;
        font-weight: bold;
    }

    .detail-actions {
        text-align: right;
        margin-top: 20px;
    }

    .detail-actions .btn {
        margin-left: 10px;
    }

    .text-danger {
        color: #dc3545;
    }

    .text-warning {
        color: #ffc107;
    }

    /* Select2样式修正 */
    .select2-container {
        width: 100% !important;
    }

    .select2-container .select2-selection--single {
        height: 38px !important;
    }

    .select2-container--default .select2-selection--single .select2-selection__rendered {
        line-height: 38px !important;
    }

    .select2-container--default .select2-selection--single .select2-selection__arrow {
        height: 36px !important;
    }

    /* 搜索表单样式 */
    .search-form {
        display: flex;
        flex-wrap: wrap;
        gap: 10px;
        align-items: center;
    }

    .search-group {
        min-width: 150px;
    }

    .search-group select,
    .search-group input {
        width: 100%;
        padding: 8px;
        border: 1px solid #ddd;
        border-radius: 4px;
    }

    .search-group input.date {
        width: 130px;
    }

    @media (max-width: 768px) {
        .detail-content {
            grid-template-columns: 1fr;
        }

        .search-form {
            flex-direction: column;
            align-items: stretch;
        }

        .search-group {
            width: 100%;
        }
    }
</style>

<script>
    // 初始化Select2
    $(document).ready(function() {
        $('.select2-product').select2({
            placeholder: "请选择商品",
            allowClear: true,
            width: '100%'
        });
    });
</script>