<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 初始化变量
$message = '';
$messageType = '';

// 检查会话中是否有消息
if (isset($_SESSION['message']) && !empty($_SESSION['message'])) {
    $message = $_SESSION['message'];
    $messageType = isset($_SESSION['message_type']) ? $_SESSION['message_type'] : 'info';

    // 清除会话消息，防止刷新页面后重复显示
    unset($_SESSION['message']);
    unset($_SESSION['message_type']);
}

// 定义通用函数，使用 if(!function_exists) 避免重复声明
if (!function_exists('getActivityTypeName')) {
    function getActivityTypeName($type)
    {
        switch ($type) {
            case 'discount':
                return '折扣';
            case 'full_reduction':
                return '满减';
            case 'package':
                return '套餐';
            default:
                return '未知';
        }
    }
}

if (!function_exists('getStatusName')) {
    function getStatusName($status)
    {
        return $status ? '激活' : '停用';
    }
}

if (!function_exists('getStatusClass')) {
    function getStatusClass($status)
    {
        return $status ? 'success' : 'secondary';
    }
}

// 检查是否有action参数
$action = isset($_GET['action']) ? $_GET['action'] : '';

// 如果有action参数，则包含对应的文件
if ($action) {
    $action_file = 'activity_' . $action . '.php';
    if (file_exists($action_file)) {
        include_once $action_file;
        exit;
    }
}

// 获取活动列表参数
$page = isset($_GET['listpage']) ? intval($_GET['listpage']) : 1;
$limit = 10;
$offset = ($page - 1) * $limit;

// 获取搜索参数
$keyword = isset($_GET['keyword']) ? sanitize($_GET['keyword']) : '';
$status = isset($_GET['status']) && $_GET['status'] !== '' ? intval($_GET['status']) : '';

// 处理删除活动
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $activityId = intval($_GET['id']);

    // 先删除关联的商品记录
    $sql = "DELETE FROM promotion_products WHERE activity_id = ?";
    $stmt = $conn->prepare($sql);
    if ($stmt) {
        $stmt->bind_param("i", $activityId);
        $stmt->execute();
        $stmt->close();
    }

    // 再删除活动本身
    $sql = "DELETE FROM promotion_activities WHERE activity_id = ?";
    $stmt = $conn->prepare($sql);
    if ($stmt) {
        $stmt->bind_param("i", $activityId);
        if ($stmt->execute()) {
            // 记录操作日志
            $operationDetails = "用户 {$_SESSION['username']} 删除了ID为{$activityId}的促销活动";
            log_operation($_SESSION['user_id'], '删除', $operationDetails);

            // 显示成功消息
            echo '<div class="alert alert-success">促销活动删除成功</div>';
        } else {
            echo '<div class="alert alert-error">促销活动删除失败: ' . $conn->error . '</div>';
        }
        $stmt->close();
    } else {
        echo '<div class="alert alert-error">系统错误: ' . $conn->error . '</div>';
    }
}

// 处理批量操作
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['batch_action']) && isset($_POST['selected_ids'])) {
    $action = $_POST['batch_action'];
    $selected_ids_str = $_POST['selected_ids'];

    if (!empty($selected_ids_str)) {
        $selected_ids = explode(',', $selected_ids_str);
        $selected_ids = array_map('intval', $selected_ids);

        if (!empty($selected_ids)) {
            $status = ($action == 'activate') ? 1 : 0;
            $placeholders = implode(',', array_fill(0, count($selected_ids), '?'));

            $sql = "UPDATE promotion_activities SET is_active = ? WHERE activity_id IN ($placeholders)";
            $stmt = $conn->prepare($sql);

            if ($stmt) {
                $types = 'i' . str_repeat('i', count($selected_ids));
                $params = array_merge([$status], $selected_ids);
                $stmt->bind_param($types, ...$params);

                if ($stmt->execute()) {
                    $action_text = $action == 'activate' ? '激活' : '停用';
                    $message = '已成功' . $action_text . '所选促销活动';
                    $messageType = 'success';

                    // 记录操作日志
                    $operationDetails = "用户 {$_SESSION['username']} 批量{$action_text}了促销活动：" . implode(',', $selected_ids);
                    log_operation($_SESSION['user_id'], '批量操作', $operationDetails);
                } else {
                    $message = '操作失败: ' . $conn->error;
                    $messageType = 'error';
                }
                $stmt->close();
            }
        } else {
            $message = '请选择要操作的促销活动';
            $messageType = 'error';
        }
    } else {
        $message = '请选择要操作的促销活动';
        $messageType = 'error';
    }
}

// 构建查询
$sql = "SELECT * FROM promotion_activities WHERE 1=1";
$countSql = "SELECT COUNT(*) AS total FROM promotion_activities WHERE 1=1";
$params = [];
$types = '';

// 添加搜索条件
if (!empty($keyword)) {
    $sql .= " AND (activity_name LIKE ? OR description LIKE ?)";
    $countSql .= " AND (activity_name LIKE ? OR description LIKE ?)";
    $params[] = "%$keyword%";
    $params[] = "%$keyword%";
    $types .= 'ss';
}

if ($status !== '') {
    $sql .= " AND is_active = ?";
    $countSql .= " AND is_active = ?";
    $params[] = $status;
    $types .= 'i';
}

// 添加排序和分页
$sql .= " ORDER BY activity_id DESC LIMIT ?, ?";
$params[] = $offset;
$params[] = $limit;
$types .= 'ii';

// 执行查询
$result = executeQuery($conn, $sql, $types, $params);
$activities = $result['success'] ? $result['data'] : [];

// 获取总记录数
$countResult = executeQuery($conn, $countSql, substr($types, 0, -2), array_slice($params, 0, -2));
$total = $countResult['success'] && !empty($countResult['data']) ? $countResult['data'][0]['total'] : 0;

// 活动类型和状态转换函数已移至文件顶部
?>

<div class="page-header">
    <div class="header-flex">
        <h3>促销活动管理</h3>
    </div>
</div>

<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<div class="module-tools">
    <div class="tools-left">
        <button onclick="executeBatchAction('activate')" class="btn btn-success">批量激活</button>
        <button onclick="executeBatchAction('deactivate')" class="btn btn-warning">批量停用</button>
    </div>
    <div class="tools-right">
        <a href="index.php?page=activity&action=add" class="btn btn-primary">添加新活动</a>
    </div>
</div>

<!-- 批量操作表单 -->
<form id="batch-form" action="index.php?page=activity" method="post" class="batch-form">
    <input type="hidden" name="batch_action" id="batch_action" value="">
    <input type="hidden" name="selected_ids" id="selected_ids" value="">
</form>

<!-- 搜索表单 -->
<div class="search-container">
    <form action="" method="get" class="search-form">
        <input type="hidden" name="page" value="activity">
        <div class="form-group">
            <select name="status" class="form-control">
                <option value="" <?php echo $status === '' ? 'selected' : ''; ?>>全部状态</option>
                <option value="1" <?php echo $status === '1' ? 'selected' : ''; ?>>激活</option>
                <option value="0" <?php echo $status === '0' ? 'selected' : ''; ?>>停用</option>
            </select>
        </div>
        <div class="form-group">
            <input type="text" name="keyword" placeholder="活动名称/描述" class="form-control search-input" value="<?php echo htmlspecialchars($keyword); ?>">
        </div>
        <div class="form-group">
            <button type="submit" class="btn btn-secondary">搜索</button>
            <a href="index.php?page=activity" class="btn btn-secondary">重置</a>
        </div>
    </form>
</div>

<form method="post" id="items-form">
    <table class="data-table">
        <thead>
            <tr>
                <th width="20"><input type="checkbox" id="select-all"></th>
                <th width="60">ID</th>
                <th width="250">活动名称</th>
                <th width="90">活动类型</th>
                <th width="180">时间范围</th>
                <th width="80">状态</th>
                <th width="300">操作</th>
            </tr>
        </thead>
        <tbody>
            <?php if (count($activities) > 0): ?>
                <?php foreach ($activities as $activity): ?>
                    <tr>
                        <td><input type="checkbox" name="select_item[]" class="item-checkbox" value="<?php echo $activity['activity_id']; ?>"></td>
                        <td><?php echo $activity['activity_id']; ?></td>
                        <td class="activity-name"><?php echo htmlspecialchars($activity['activity_name']); ?></td>
                        <td><?php echo getActivityTypeName($activity['activity_type']); ?></td>
                        <td><?php echo $activity['start_date'] . '<br>' . $activity['end_date']; ?></td>
                        <td>
                            <span class="badge badge-<?php echo getStatusClass($activity['is_active']); ?>">
                                <?php echo getStatusName($activity['is_active']); ?>
                            </span>
                        </td>
                        <td class="actions">
                            <a href="index.php?page=activity&action=products&id=<?php echo $activity['activity_id']; ?>" class="btn btn-info btn-sm">关联商品</a>
                            <a href="index.php?page=activity&action=view&id=<?php echo $activity['activity_id']; ?>" class="btn btn-secondary btn-sm">查看</a>
                            <a href="index.php?page=activity&action=edit&id=<?php echo $activity['activity_id']; ?>" class="btn btn-primary btn-sm">编辑</a>
                            <a href="index.php?page=activity&action=delete&id=<?php echo $activity['activity_id']; ?>" class="btn btn-danger btn-sm" onclick="return confirm('确定要删除此促销活动吗？')">删除</a>
                        </td>
                    </tr>
                <?php endforeach; ?>
            <?php else: ?>
                <tr>
                    <td colspan="7" class="text-center">没有找到促销活动记录</td>
                </tr>
            <?php endif; ?>
        </tbody>
    </table>
</form>

<!-- 分页 -->
<?php
$queryParams = [];
if (!empty($keyword)) $queryParams[] = "keyword=" . urlencode($keyword);
if ($status !== '') $queryParams[] = "status=$status";
$queryString = !empty($queryParams) ? '&' . implode('&', $queryParams) : '';
echo generate_pagination($total, $page, $limit, "index.php?page=activity" . $queryString . "&listpage=");
?>

<style>
    .badge {
        display: inline-block;
        padding: 3px 8px;
        font-size: 12px;
        font-weight: 600;
        border-radius: 3px;
        color: white;
    }

    .badge-success {
        background-color: #28a745;
    }

    .badge-secondary {
        background-color: #6c757d;
    }

    .badge-info {
        background-color: #17a2b8;
    }

    .text-center {
        text-align: center;
    }

    .form-control {
        padding: 8px 12px;
        border: 1px solid #ced4da;
        border-radius: 4px;
        min-width: 120px;
    }

    .btn-info {
        background-color: #17a2b8;
        color: #fff;
    }

    .btn-info:hover {
        background-color: #138496;
        text-decoration: none;
    }

    /* 修改样式解决错位问题 */
    .activity-name {
        max-width: 250px;
        overflow: hidden;
        text-overflow: ellipsis;
        white-space: nowrap;
    }

    .data-table th,
    .data-table td {
        padding: 1px;
        vertical-align: middle;
    }

    .data-table {
        table-layout: fixed;
        width: 100%;
        border-collapse: collapse;
    }

    .actions {
        white-space: nowrap;
        min-height: 60px;
        display: flex;
        flex-wrap: wrap;
        align-items: center;
        justify-content: center;
    }

    .btn-sm {
        margin: 2px;
        padding: 4px 8px;
        font-size: 12px;
        line-height: 1.5;
    }

    th:last-child,
    td:last-child {
        text-align: center;
    }

    .header-flex {
        display: flex;
        justify-content: space-between;
        align-items: center;
        margin-bottom: 20px;
    }

    .module-tools {
        display: flex;
        justify-content: space-between;
        margin-bottom: 15px;
    }

    .tools-left,
    .tools-right {
        display: flex;
        gap: 10px;
    }

    .search-container {
        background-color: #f5f5f5;
        padding: 15px;
        border-radius: 5px;
        margin-bottom: 20px;
    }

    .search-form {
        display: flex;
        flex-wrap: wrap;
        gap: 10px;
        align-items: center;
    }

    .search-form .form-group {
        margin-bottom: 0;
    }

    .search-input {
        min-width: 250px;
    }

    .batch-form {
        display: inline;
    }

    @media (max-width: 768px) {

        .header-flex,
        .module-tools {
            flex-direction: column;
            align-items: flex-start;
        }

        .tools-right {
            margin-top: 10px;
        }

        .search-form {
            flex-direction: column;
            align-items: stretch;
        }

        .search-form .form-group {
            margin-bottom: 10px;
        }
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 全选功能
        const selectAll = document.getElementById('select-all');
        const checkboxes = document.querySelectorAll('.item-checkbox');

        if (selectAll) {
            selectAll.addEventListener('change', function() {
                checkboxes.forEach(checkbox => {
                    checkbox.checked = this.checked;
                });
            });
        }

        checkboxes.forEach(checkbox => {
            checkbox.addEventListener('change', function() {
                // 检查是否所有复选框都被选中
                if (selectAll) {
                    const allChecked = Array.from(checkboxes).every(cb => cb.checked);
                    selectAll.checked = allChecked;
                }
            });
        });

        function confirmDelete(id, name) {
            if (confirm('确定要删除活动 "' + name + '" 吗？此操作不可撤销！')) {
                window.location.href = 'index.php?page=activity&action=delete&id=' + id;
            }
        }
    });

    // 批量操作处理函数
    function executeBatchAction(action) {
        const checkboxes = document.querySelectorAll('.item-checkbox:checked');
        if (checkboxes.length === 0) {
            alert('请至少选择一个活动');
            return;
        }

        const ids = Array.from(checkboxes).map(cb => cb.value);

        // 设置隐藏字段的值
        document.getElementById('batch_action').value = action;
        document.getElementById('selected_ids').value = ids.join(',');

        // 提交表单
        document.getElementById('batch-form').submit();
    }
</script>