<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 初始化消息变量
$message = '';
$messageType = '';
$activity_type = isset($_POST['activity_type']) ? $_POST['activity_type'] : '';
$discount_rate = isset($_POST['discount_rate']) ? $_POST['discount_rate'] : '0.80';
$min_amount = isset($_POST['min_amount']) ? $_POST['min_amount'] : '';
$reduction_amount = isset($_POST['reduction_amount']) ? $_POST['reduction_amount'] : '';

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // 获取表单数据
    $activity_name = isset($_POST['activity_name']) ? sanitize($_POST['activity_name']) : '';
    $activity_type = isset($_POST['activity_type']) ? sanitize($_POST['activity_type']) : '';
    $start_date = isset($_POST['start_date']) ? sanitize($_POST['start_date']) : '';
    $end_date = isset($_POST['end_date']) ? sanitize($_POST['end_date']) : '';
    $is_active = isset($_POST['is_active']) ? 1 : 0;
    $discount_rate = isset($_POST['discount_rate']) ? (float)($_POST['discount_rate']) : 0;
    $min_amount = isset($_POST['min_amount']) ? (float)($_POST['min_amount']) : 0;
    $reduction_amount = isset($_POST['reduction_amount']) ? (float)($_POST['reduction_amount']) : 0;
    $description = isset($_POST['description']) ? sanitize($_POST['description']) : '';

    // 验证数据
    $errors = [];
    if (empty($activity_name)) {
        $errors[] = '活动名称不能为空';
    }

    if (empty($activity_type)) {
        $errors[] = '请选择活动类型';
    }

    if (empty($start_date)) {
        $errors[] = '开始日期不能为空';
    }

    if (empty($end_date)) {
        $errors[] = '结束日期不能为空';
    }

    if ($activity_type == 'discount' && (empty($discount_rate) || $discount_rate <= 0 || $discount_rate > 1)) {
        $errors[] = '折扣类型活动的折扣率必须大于0且小于等于1';
    }

    if ($activity_type == 'full_reduction' && (empty($min_amount) || $min_amount <= 0)) {
        $errors[] = '满减类型活动的最低金额必须大于0';
    }

    if ($activity_type == 'full_reduction' && (empty($reduction_amount) || $reduction_amount <= 0)) {
        $errors[] = '满减类型活动的减免金额必须大于0';
    }

    // 检查日期有效性
    if (!empty($start_date) && !empty($end_date)) {
        $start_timestamp = strtotime($start_date);
        $end_timestamp = strtotime($end_date);

        if ($start_timestamp === false || $end_timestamp === false) {
            $errors[] = '日期格式无效';
        } elseif ($start_timestamp > $end_timestamp) {
            $errors[] = '开始日期不能晚于结束日期';
        }
    }

    // 如果没有错误，则保存数据
    if (empty($errors)) {
        // 准备SQL语句
        $sql = "INSERT INTO promotion_activities (activity_name, activity_type, start_date, end_date, is_active, discount_rate, min_amount, reduction_amount, description, created_by) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";

        $stmt = $conn->prepare($sql);
        if ($stmt) {
            // 绑定参数
            $stmt->bind_param("ssssiddisi", $activity_name, $activity_type, $start_date, $end_date, $is_active, $discount_rate, $min_amount, $reduction_amount, $description, $_SESSION['user_id']);

            // 执行
            if ($stmt->execute()) {
                $new_activity_id = $stmt->insert_id;

                // 记录操作日志
                $operationDetails = "用户 {$_SESSION['username']} 添加了新促销活动：{$activity_name}";
                log_operation($_SESSION['user_id'], '添加', $operationDetails);

                // 设置成功消息并重定向回列表页
                $_SESSION['message'] = '新促销活动 "' . $activity_name . '" 添加成功';
                $_SESSION['message_type'] = 'success';

                // 跳转到活动列表页面
                header("Location: index.php?page=activity");
                exit;
            } else {
                $message = '添加促销活动失败: ' . $stmt->error;
                $messageType = 'error';
            }
            $stmt->close();
        } else {
            $message = '系统错误: ' . $conn->error;
            $messageType = 'error';
        }
    } else {
        // 显示验证错误
        $message = implode('<br>', $errors);
        $messageType = 'error';
    }
}

if (!function_exists('getActivityTypeName')) {
    function getActivityTypeName($type)
    {
        switch ($type) {
            case 'discount':
                return '折扣';
            case 'full_reduction':
                return '满减';
            case 'package':
                return '套餐';
            default:
                return '未知';
        }
    }
}
?>

<div class="page-header">
    <h3>添加新促销活动</h3>
</div>

<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<div class="form-wrapper">
    <form action="index.php?page=activity&action=add" method="post" class="data-form">
        <div class="form-group">
            <label for="activity_name">活动名称 <span class="required">*</span></label>
            <input type="text" id="activity_name" name="activity_name" class="form-control" value="<?php echo isset($_POST['activity_name']) ? htmlspecialchars($_POST['activity_name']) : ''; ?>" required>
        </div>

        <div class="form-group">
            <label for="activity_type">活动类型 <span class="required">*</span></label>
            <select id="activity_type" name="activity_type" class="form-control" required>
                <option value="">请选择</option>
                <option value="discount" <?php echo isset($_POST['activity_type']) && $_POST['activity_type'] == 'discount' ? 'selected' : ''; ?>>折扣</option>
                <option value="full_reduction" <?php echo isset($_POST['activity_type']) && $_POST['activity_type'] == 'full_reduction' ? 'selected' : ''; ?>>满减</option>
                <option value="package" <?php echo isset($_POST['activity_type']) && $_POST['activity_type'] == 'package' ? 'selected' : ''; ?>>套餐</option>
            </select>
        </div>

        <div class="form-row">
            <div class="form-group half">
                <label for="start_date">开始日期 <span class="required">*</span></label>
                <input type="date" id="start_date" name="start_date" class="form-control" value="<?php echo isset($_POST['start_date']) ? htmlspecialchars($_POST['start_date']) : date('Y-m-d'); ?>" required>
            </div>

            <div class="form-group half">
                <label for="end_date">结束日期 <span class="required">*</span></label>
                <input type="date" id="end_date" name="end_date" class="form-control" value="<?php echo isset($_POST['end_date']) ? htmlspecialchars($_POST['end_date']) : date('Y-m-d', strtotime('+30 days')); ?>" required>
            </div>
        </div>

        <div class="form-group">
            <label for="is_active">
                <input type="checkbox" id="is_active" name="is_active" <?php echo !isset($_POST['is_active']) || $_POST['is_active'] ? 'checked' : ''; ?>>
                激活活动
            </label>
        </div>

        <div id="discount_fields" class="dynamic-fields" style="display: none;">
            <div class="form-group discount-field" <?php echo $activity_type !== 'discount' ? 'style="display: none;"' : ''; ?>>
                <label for="discount_rate">折扣率 <span class="required">*</span></label>
                <input type="number" id="discount_rate" name="discount_rate" class="form-control" value="<?php echo $discount_rate; ?>" step="0.01" min="0.01" max="0.99" required>
                <small>请输入0.01到0.99之间的数字，表示折扣比例，如0.8表示8折</small>
            </div>
        </div>

        <div id="full_reduction_fields" class="dynamic-fields" style="display: none;">
            <div class="form-group">
                <label for="min_amount">最低金额 <span class="required">*</span></label>
                <input type="number" id="min_amount" name="min_amount" class="form-control" value="<?php echo isset($_POST['min_amount']) ? htmlspecialchars($_POST['min_amount']) : ''; ?>" step="0.01" min="0.01">
            </div>

            <div class="form-group">
                <label for="reduction_amount">减免金额 <span class="required">*</span></label>
                <input type="number" id="reduction_amount" name="reduction_amount" class="form-control" value="<?php echo isset($_POST['reduction_amount']) ? htmlspecialchars($_POST['reduction_amount']) : ''; ?>" step="0.01" min="0.01">
            </div>
        </div>

        <div class="form-group">
            <label for="description">活动描述</label>
            <textarea id="description" name="description" class="form-control" rows="4"><?php echo isset($_POST['description']) ? htmlspecialchars($_POST['description']) : ''; ?></textarea>
        </div>

        <div class="form-actions">
            <button type="submit" class="btn btn-primary">保存</button>
            <a href="index.php?page=activity" class="btn btn-secondary">取消</a>
        </div>
    </form>
</div>

<style>
    .form-wrapper {
        background-color: #f9f9f9;
        padding: 20px;
        border-radius: 5px;
        margin-bottom: 20px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .page-header {
        margin-bottom: 20px;
    }

    .data-form {
        max-width: 800px;
    }

    .form-group {
        margin-bottom: 15px;
    }

    .form-row {
        display: flex;
        flex-wrap: wrap;
        margin-right: -10px;
        margin-left: -10px;
    }

    .form-group.half {
        flex: 0 0 50%;
        max-width: 50%;
        padding-right: 10px;
        padding-left: 10px;
        box-sizing: border-box;
    }

    .form-control {
        display: block;
        width: 100%;
        padding: 8px 12px;
        font-size: 14px;
        line-height: 1.5;
        color: #495057;
        background-color: #fff;
        border: 1px solid #ced4da;
        border-radius: 4px;
        transition: border-color 0.15s ease-in-out;
    }

    .form-control:focus {
        border-color: #80bdff;
        outline: 0;
    }

    .form-actions {
        margin-top: 20px;
        padding-top: 15px;
        border-top: 1px solid #e9ecef;
    }

    .required {
        color: #dc3545;
    }

    label {
        font-weight: bold;
        margin-bottom: 5px;
        display: block;
    }

    small {
        display: block;
        margin-top: 5px;
        color: #6c757d;
    }

    @media (max-width: 767.98px) {
        .form-group.half {
            flex: 0 0 100%;
            max-width: 100%;
        }
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        const activityType = document.getElementById('activity_type');
        const discountFields = document.getElementById('discount_fields');
        const fullReductionFields = document.getElementById('full_reduction_fields');
        const discountRateInput = document.getElementById('discount_rate');
        const minAmountInput = document.getElementById('min_amount');
        const reductionAmountInput = document.getElementById('reduction_amount');

        // 初始化页面时更新字段显示
        updateFieldsVisibility(activityType.value);

        // 当活动类型变化时，更新字段显示
        activityType.addEventListener('change', function() {
            updateFieldsVisibility(this.value);
        });

        function updateFieldsVisibility(type) {
            if (type === 'discount') {
                discountFields.style.display = 'block';
                fullReductionFields.style.display = 'none';
                discountRateInput.setAttribute('required', 'required');
                minAmountInput.removeAttribute('required');
                reductionAmountInput.removeAttribute('required');
            } else if (type === 'full_reduction') {
                discountFields.style.display = 'none';
                fullReductionFields.style.display = 'block';
                discountRateInput.removeAttribute('required');
                minAmountInput.setAttribute('required', 'required');
                reductionAmountInput.setAttribute('required', 'required');
            } else {
                discountFields.style.display = 'none';
                fullReductionFields.style.display = 'none';
                discountRateInput.removeAttribute('required');
                minAmountInput.removeAttribute('required');
                reductionAmountInput.removeAttribute('required');
            }
        }
    });
</script>