<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 获取活动ID
$activity_id = isset($_GET['id']) ? intval($_GET['id']) : 0;

if ($activity_id <= 0) {
    echo '<div class="alert alert-error">无效的活动ID</div>';
    echo '<div class="form-actions"><a href="index.php?page=activity" class="btn btn-primary">返回活动列表</a></div>';
    exit;
}

// 获取活动信息
$sql = "SELECT a.*, u.username as creator_name 
        FROM promotion_activities a 
        LEFT JOIN users u ON a.created_by = u.user_id 
        WHERE a.activity_id = ?";
$result = executeQuery($conn, $sql, 'i', [$activity_id]);

if (!$result['success'] || empty($result['data'])) {
    echo '<div class="alert alert-error">未找到该促销活动</div>';
    echo '<div class="form-actions"><a href="index.php?page=activity" class="btn btn-primary">返回活动列表</a></div>';
    exit;
}

$activity = $result['data'][0];

// 获取关联的商品
$productSql = "SELECT pp.*, p.product_name, p.barcode, p.unit, p.unit_price 
               FROM promotion_products pp 
               JOIN products p ON pp.product_id = p.product_id 
               WHERE pp.activity_id = ?";
$productResult = executeQuery($conn, $productSql, 'i', [$activity_id]);
$products = $productResult['success'] ? $productResult['data'] : [];

// 活动类型和状态转换函数
if (!function_exists('getActivityTypeName')) {
    function getActivityTypeName($type)
    {
        switch ($type) {
            case 'discount':
                return '折扣';
            case 'full_reduction':
                return '满减';
            case 'package':
                return '套餐';
            default:
                return '未知';
        }
    }
}

if (!function_exists('getStatusName')) {
    function getStatusName($status)
    {
        return $status ? '激活' : '停用';
    }
}

if (!function_exists('getStatusClass')) {
    function getStatusClass($status)
    {
        return $status ? 'success' : 'secondary';
    }
}
?>

<div class="activity-details">
    <h3>促销活动详情</h3>

    <div class="detail-group">
        <label>活动ID:</label>
        <span><?php echo $activity['activity_id']; ?></span>
    </div>

    <div class="detail-group">
        <label>活动名称:</label>
        <span><?php echo htmlspecialchars($activity['activity_name']); ?></span>
    </div>

    <div class="detail-group">
        <label>活动类型:</label>
        <span><?php echo getActivityTypeName($activity['activity_type']); ?></span>
    </div>

    <div class="detail-group">
        <label>开始日期:</label>
        <span><?php echo $activity['start_date']; ?></span>
    </div>

    <div class="detail-group">
        <label>结束日期:</label>
        <span><?php echo $activity['end_date']; ?></span>
    </div>

    <div class="detail-group">
        <label>活动状态:</label>
        <span class="badge badge-<?php echo getStatusClass($activity['is_active']); ?>">
            <?php echo getStatusName($activity['is_active']); ?>
        </span>
    </div>

    <?php if ($activity['activity_type'] == 'discount' && $activity['discount_rate'] !== null): ?>
        <div class="detail-group">
            <label>折扣率:</label>
            <span><?php echo number_format($activity['discount_rate'] * 100, 1); ?>%</span>
        </div>
    <?php endif; ?>

    <?php if ($activity['activity_type'] == 'full_reduction'): ?>
        <?php if ($activity['min_amount'] !== null): ?>
            <div class="detail-group">
                <label>最低金额:</label>
                <span>¥<?php echo number_format($activity['min_amount'], 2); ?></span>
            </div>
        <?php endif; ?>

        <?php if ($activity['reduction_amount'] !== null): ?>
            <div class="detail-group">
                <label>减免金额:</label>
                <span>¥<?php echo number_format($activity['reduction_amount'], 2); ?></span>
            </div>
        <?php endif; ?>
    <?php endif; ?>

    <div class="detail-group">
        <label>活动描述:</label>
        <span><?php echo !empty($activity['description']) ? nl2br(htmlspecialchars($activity['description'])) : '无'; ?></span>
    </div>

    <div class="detail-group">
        <label>创建人:</label>
        <span><?php echo htmlspecialchars($activity['creator_name']); ?></span>
    </div>

    <div class="detail-group">
        <label>创建时间:</label>
        <span><?php echo $activity['created_at']; ?></span>
    </div>

    <div class="detail-group">
        <label>最后更新:</label>
        <span><?php echo $activity['updated_at']; ?></span>
    </div>
</div>

<div class="activity-products">
    <h3>关联商品列表</h3>

    <?php if (count($products) > 0): ?>
        <table class="data-table">
            <thead>
                <tr>
                    <th>商品名称</th>
                    <th>条码</th>
                    <th>单位</th>
                    <th>单价</th>
                    <?php if ($activity['activity_type'] == 'discount'): ?>
                        <th>商品特定折扣</th>
                    <?php endif; ?>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($products as $product): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($product['product_name']); ?></td>
                        <td><?php echo htmlspecialchars($product['barcode']); ?></td>
                        <td><?php echo htmlspecialchars($product['unit']); ?></td>
                        <td>¥<?php echo number_format($product['unit_price'], 2); ?></td>
                        <?php if ($activity['activity_type'] == 'discount'): ?>
                            <td>
                                <?php
                                if (!empty($product['discount_rate'])) {
                                    echo number_format($product['discount_rate'] * 100, 1) . '%';
                                } else {
                                    echo '使用活动折扣';
                                }
                                ?>
                            </td>
                        <?php endif; ?>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    <?php else: ?>
        <div class="alert alert-info">该活动尚未关联任何商品</div>
    <?php endif; ?>
</div>

<div class="detail-actions">
    <a href="index.php?page=activity" class="btn btn-secondary">返回活动列表</a>
    <a href="index.php?page=activity&action=edit&id=<?php echo $activity_id; ?>" class="btn btn-primary">编辑活动</a>
    <a href="index.php?page=activity&action=products&id=<?php echo $activity_id; ?>" class="btn btn-info">管理关联商品</a>
</div>

<style>
    .activity-details,
    .activity-products {
        background-color: #f9f9f9;
        padding: 20px;
        border-radius: 5px;
        margin-bottom: 20px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        border: 1px solid #e0e0e0;
    }

    .activity-details h3,
    .activity-products h3 {
        margin-top: 0;
        margin-bottom: 20px;
        color: #333;
        border-bottom: 1px solid #ddd;
        padding-bottom: 10px;
        font-size: 1.2em;
    }

    .detail-group {
        margin-bottom: 12px;
        display: flex;
        align-items: flex-start;
        border-bottom: 1px dashed #eee;
        padding-bottom: 8px;
    }

    .detail-group:last-of-type {
        border-bottom: none;
    }

    .detail-group label {
        font-weight: bold;
        width: 120px;
        color: #555;
        flex-shrink: 0;
    }

    .detail-group span {
        flex-grow: 1;
        color: #333;
    }

    .detail-actions {
        margin-top: 20px;
        padding-top: 15px;
        display: flex;
        gap: 10px;
    }

    .detail-actions .btn {
        padding: 8px 16px;
        text-decoration: none;
        border-radius: 4px;
        font-weight: normal;
        text-align: center;
    }

    .badge {
        display: inline-block;
        padding: 3px 8px;
        font-size: 12px;
        font-weight: 600;
        border-radius: 3px;
        color: white;
    }

    .badge-success {
        background-color: #28a745;
    }

    .badge-secondary {
        background-color: #6c757d;
    }

    .badge-info {
        background-color: #17a2b8;
    }

    .btn-info {
        background-color: #17a2b8;
        color: #fff;
    }

    .btn-info:hover {
        background-color: #138496;
        text-decoration: none;
    }
</style>