<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 初始化消息变量
$message = '';
$messageType = '';

// 获取会员ID
$member_id = isset($_GET['id']) ? intval($_GET['id']) : 0;

if ($member_id <= 0) {
    echo '<div class="alert alert-error">无效的会员ID</div>';
    echo '<div class="form-actions"><a href="index.php?page=member" class="btn btn-primary">返回会员列表</a></div>';
    exit;
}

// 获取会员等级信息
$levelSql = "SELECT * FROM member_levels ORDER BY min_points ASC";
$levelResult = $conn->query($levelSql);
$memberLevels = [];
while ($levelResult && $row = $levelResult->fetch_assoc()) {
    $memberLevels[$row['level_id']] = $row;
}

// 获取会员信息
$sql = "SELECT m.*, c.customer_name, c.phone 
        FROM members m 
        INNER JOIN customers c ON m.customer_id = c.customer_id 
        WHERE m.member_id = ?";
$stmt = $conn->prepare($sql);
if (!$stmt) {
    echo '<div class="alert alert-error">查询准备失败: ' . $conn->error . '</div>';
    echo '<div class="form-actions"><a href="index.php?page=member" class="btn btn-primary">返回会员列表</a></div>';
    exit;
}

$stmt->bind_param("i", $member_id);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows === 0) {
    echo '<div class="alert alert-error">未找到会员记录</div>';
    echo '<div class="form-actions"><a href="index.php?page=member" class="btn btn-primary">返回会员列表</a></div>';
    exit;
}

$member = $result->fetch_assoc();
$stmt->close();

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // 获取表单数据
    $member_no = isset($_POST['member_no']) ? sanitize($_POST['member_no']) : '';
    $level_id = isset($_POST['level_id']) ? intval($_POST['level_id']) : 0;
    $points = isset($_POST['points']) ? intval($_POST['points']) : 0;
    $status = isset($_POST['status']) ? sanitize($_POST['status']) : 'active';
    $remark = isset($_POST['remark']) ? sanitize($_POST['remark']) : '';

    // 验证数据
    $errors = [];
    if (empty($member_no)) {
        $errors[] = '会员卡号不能为空';
    } else {
        // 检查会员卡号是否已存在（排除当前记录）
        $checkSql = "SELECT COUNT(*) as count FROM members WHERE member_no = ? AND member_id != ?";
        $stmt = $conn->prepare($checkSql);
        if ($stmt) {
            $stmt->bind_param("si", $member_no, $member_id);
            $stmt->execute();
            $result = $stmt->get_result();
            if ($result && $result->fetch_assoc()['count'] > 0) {
                $errors[] = '会员卡号已存在，请使用其他卡号';
            }
            $stmt->close();
        }
    }

    if (empty($level_id)) {
        $errors[] = '请选择会员等级';
    }

    if ($points < 0) {
        $errors[] = '积分不能为负数';
    }

    // 如果没有错误，则更新数据
    if (empty($errors)) {
        // 准备SQL语句
        $sql = "UPDATE members SET 
                member_no = ?, 
                level_id = ?, 
                points = ?, 
                status = ?, 
                remark = ? 
                WHERE member_id = ?";

        $stmt = $conn->prepare($sql);
        if ($stmt) {
            // 绑定参数
            $stmt->bind_param("siissi", $member_no, $level_id, $points, $status, $remark, $member_id);

            // 执行
            if ($stmt->execute()) {
                // 记录操作日志
                $operationDetails = "用户 {$_SESSION['username']} 更新了会员信息，会员ID：{$member_id}，会员卡号：{$member_no}";
                log_operation($_SESSION['user_id'], '更新', $operationDetails);

                // 设置成功消息并重定向回列表页
                $_SESSION['message'] = '会员信息更新成功';
                $_SESSION['message_type'] = 'success';

                // 跳转到会员列表页面
                header("Location: index.php?page=member");
                exit;
            } else {
                $message = '更新会员失败: ' . $stmt->error;
                $messageType = 'error';
            }
            $stmt->close();
        } else {
            $message = '系统错误: ' . $conn->error;
            $messageType = 'error';
        }
    } else {
        // 显示验证错误
        $message = implode('<br>', $errors);
        $messageType = 'error';
    }
}
?>

<div class="page-header">
    <h3>编辑会员信息</h3>
</div>

<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<div class="form-wrapper">
    <form action="index.php?page=member&action=edit&id=<?php echo $member_id; ?>" method="post" class="data-form">
        <div class="form-group">
            <label for="customer_id">客户信息</label>
            <input type="text" class="form-control" value="<?php echo htmlspecialchars($member['customer_name']); ?> (<?php echo htmlspecialchars($member['phone'] ?: '无电话'); ?>)" readonly>
            <small>会员关联的客户信息不可修改，如需更改请删除会员后重新添加</small>
        </div>

        <div class="form-group">
            <label for="member_no">会员卡号 <span class="required">*</span></label>
            <input type="text" id="member_no" name="member_no" class="form-control" value="<?php echo htmlspecialchars(isset($_POST['member_no']) ? $_POST['member_no'] : $member['member_no']); ?>" required>
            <small>会员卡号必须唯一</small>
        </div>

        <div class="form-group">
            <label for="level_id">会员等级 <span class="required">*</span></label>
            <select id="level_id" name="level_id" class="form-control" required>
                <option value="">-- 请选择会员等级 --</option>
                <?php foreach ($memberLevels as $level): ?>
                    <option value="<?php echo $level['level_id']; ?>" <?php echo (isset($_POST['level_id']) ? $_POST['level_id'] : $member['level_id']) == $level['level_id'] ? 'selected' : ''; ?>>
                        <?php echo htmlspecialchars($level['level_name']); ?>
                        (折扣率: <?php echo $level['discount_rate']; ?>, 最低积分: <?php echo $level['min_points']; ?>)
                    </option>
                <?php endforeach; ?>
            </select>
        </div>

        <div class="form-row">
            <div class="form-group half">
                <label for="points">当前积分</label>
                <input type="number" id="points" name="points" class="form-control" value="<?php echo isset($_POST['points']) ? intval($_POST['points']) : $member['points']; ?>" min="0">
                <small>直接在此修改会员积分</small>
            </div>

            <div class="form-group half">
                <label for="join_date">入会日期</label>
                <input type="date" id="join_date" class="form-control" value="<?php echo htmlspecialchars($member['join_date']); ?>" readonly>
                <small>入会日期不可修改</small>
            </div>
        </div>

        <div class="form-group">
            <label for="status">会员状态</label>
            <select id="status" name="status" class="form-control">
                <option value="active" <?php echo (isset($_POST['status']) ? $_POST['status'] : $member['status']) == 'active' ? 'selected' : ''; ?>>激活</option>
                <option value="inactive" <?php echo (isset($_POST['status']) ? $_POST['status'] : $member['status']) == 'inactive' ? 'selected' : ''; ?>>停用</option>
            </select>
        </div>

        <div class="form-group">
            <label for="remark">备注</label>
            <textarea id="remark" name="remark" class="form-control" rows="3"><?php echo htmlspecialchars(isset($_POST['remark']) ? $_POST['remark'] : $member['remark']); ?></textarea>
        </div>

        <div class="form-actions">
            <button type="submit" class="btn btn-primary">保存</button>
            <a href="index.php?page=member" class="btn btn-secondary">取消</a>
        </div>
    </form>
</div>

<style>
    .form-wrapper {
        background-color: #f9f9f9;
        padding: 20px;
        border-radius: 5px;
        margin-bottom: 20px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .page-header {
        margin-bottom: 20px;
    }

    .data-form {
        max-width: 800px;
    }

    .form-group {
        margin-bottom: 15px;
    }

    .form-row {
        display: flex;
        flex-wrap: wrap;
        margin-right: -10px;
        margin-left: -10px;
    }

    .form-group.half {
        flex: 0 0 50%;
        max-width: 50%;
        padding-right: 10px;
        padding-left: 10px;
        box-sizing: border-box;
    }

    .form-control {
        display: block;
        width: 100%;
        padding: 8px 12px;
        font-size: 14px;
        line-height: 1.5;
        color: #495057;
        background-color: #fff;
        border: 1px solid #ced4da;
        border-radius: 4px;
        transition: border-color 0.15s ease-in-out;
    }

    .form-control:focus {
        border-color: #80bdff;
        outline: 0;
    }

    .form-control[readonly] {
        background-color: #e9ecef;
        opacity: 1;
    }

    .form-actions {
        margin-top: 20px;
        padding-top: 15px;
        border-top: 1px solid #e9ecef;
    }

    .required {
        color: #dc3545;
    }

    label {
        font-weight: bold;
        margin-bottom: 5px;
        display: block;
    }

    small {
        display: block;
        margin-top: 5px;
        color: #6c757d;
    }

    @media (max-width: 767.98px) {
        .form-group.half {
            flex: 0 0 100%;
            max-width: 100%;
        }
    }
</style>