<?php
// 采购订单管理页面
// 防止直接访问
if (!defined('IN_SYSTEM')) {
    define('IN_SYSTEM', true);
}

// 初始化消息变量
$message = '';
$messageType = '';

// 获取采购订单列表
$orders = [];
$search = isset($_GET['keyword']) ? $_GET['keyword'] : '';

// 处理添加/编辑采购订单
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 获取表单数据
    $supplier_id = isset($_POST['supplier_id']) ? (int)$_POST['supplier_id'] : 0;
    $order_number = isset($_POST['order_number']) ? trim($_POST['order_number']) : '';
    $order_date = isset($_POST['order_date']) ? trim($_POST['order_date']) : '';
    $total_amount = isset($_POST['total_amount']) ? (float)$_POST['total_amount'] : 0;
    $status = isset($_POST['status']) ? trim($_POST['status']) : 'pending';

    // 验证数据
    if (empty($supplier_id) || empty($order_number) || empty($order_date) || $total_amount <= 0) {
        $message = '请填写所有必填字段！';
        $messageType = 'error';
    } else {
        // 添加新采购订单
        if ($_POST['action'] == 'add') {
            try {
                $sql = "INSERT INTO purchase_orders (supplier_id, order_number, order_date, total_amount, status) VALUES (?, ?, ?, ?, ?)";
                $stmt = $conn->prepare($sql);

                if ($stmt === false) {
                    $message = "准备添加采购订单的SQL语句失败: " . $conn->error;
                    $messageType = 'error';
                } else {
                    $stmt->bind_param("issds", $supplier_id, $order_number, $order_date, $total_amount, $status);

                    if ($stmt->execute()) {
                        $orderId = $stmt->insert_id;
                        $message = "采购订单 {$order_number} 添加成功！";
                        $messageType = 'success';

                        // 记录操作日志
                        $operationDetails = "用户 {$_SESSION['username']} 添加了采购订单: {$order_number}";
                        log_operation($_SESSION['user_id'], '添加采购订单', $operationDetails);

                        // 重定向到采购订单列表
                        header("Location: index.php?page=order&message={$message}&type={$messageType}");
                        exit;
                    } else {
                        $message = "添加采购订单失败: " . $stmt->error;
                        $messageType = 'error';
                    }
                    $stmt->close();
                }
            } catch (Exception $e) {
                $message = "系统错误: " . $e->getMessage();
                $messageType = 'error';
            }
        }
        // 更新采购订单
        elseif ($_POST['action'] == 'edit' && isset($_POST['order_id'])) {
            $order_id = (int)$_POST['order_id'];

            try {
                $sql = "UPDATE purchase_orders SET supplier_id = ?, order_number = ?, order_date = ?, total_amount = ?, status = ? WHERE order_id = ?";
                $stmt = $conn->prepare($sql);

                if ($stmt === false) {
                    $message = "准备更新采购订单的SQL语句失败: " . $conn->error;
                    $messageType = 'error';
                } else {
                    $stmt->bind_param("issdsi", $supplier_id, $order_number, $order_date, $total_amount, $status, $order_id);

                    if ($stmt->execute()) {
                        $message = "采购订单 {$order_number} 更新成功！";
                        $messageType = 'success';

                        // 记录操作日志
                        $operationDetails = "用户 {$_SESSION['username']} 更新了采购订单: {$order_number}";
                        log_operation($_SESSION['user_id'], '更新采购订单', $operationDetails);

                        // 重定向到采购订单列表
                        header("Location: index.php?page=order&message={$message}&type={$messageType}");
                        exit;
                    } else {
                        $message = "更新采购订单失败: " . $stmt->error;
                        $messageType = 'error';
                    }
                    $stmt->close();
                }
            } catch (Exception $e) {
                $message = "系统错误: " . $e->getMessage();
                $messageType = 'error';
            }
        }
    }
}

// 处理快速更新订单状态
if (isset($_GET['action']) && $_GET['action'] == 'update_status' && isset($_GET['id']) && isset($_GET['status'])) {
    $order_id = (int)$_GET['id'];
    $new_status = $_GET['status'];

    // 验证状态值有效性
    if (in_array($new_status, ['pending', 'approved', 'rejected'])) {
        try {
            $sql = "UPDATE purchase_orders SET status = ? WHERE order_id = ?";
            $stmt = $conn->prepare($sql);

            if ($stmt === false) {
                $message = "准备更新订单状态的SQL语句失败: " . $conn->error;
                $messageType = 'error';
            } else {
                $stmt->bind_param("si", $new_status, $order_id);

                if ($stmt->execute()) {
                    // 获取订单编号用于日志记录
                    $orderSql = "SELECT order_number FROM purchase_orders WHERE order_id = ?";
                    $orderStmt = $conn->prepare($orderSql);
                    $order_number = '';

                    if ($orderStmt !== false) {
                        $orderStmt->bind_param("i", $order_id);
                        if ($orderStmt->execute()) {
                            $orderResult = $orderStmt->get_result();
                            if ($orderResult && $orderResult->num_rows > 0) {
                                $orderData = $orderResult->fetch_assoc();
                                $order_number = $orderData['order_number'];
                            }
                        }
                        $orderStmt->close();
                    }

                    $statusText = '';
                    switch ($new_status) {
                        case 'approved':
                            $statusText = '已审核';
                            break;
                        case 'rejected':
                            $statusText = '已拒绝';
                            break;
                        default:
                            $statusText = '待审核';
                    }

                    $message = "订单 {$order_number} 状态更新为{$statusText}！";
                    $messageType = 'success';

                    // 记录操作日志
                    $operationDetails = "用户 {$_SESSION['username']} 将采购订单 {$order_number} 状态更新为{$statusText}";
                    log_operation($_SESSION['user_id'], '更新采购订单状态', $operationDetails);
                } else {
                    $message = "更新订单状态失败: " . $stmt->error;
                    $messageType = 'error';
                }
                $stmt->close();
            }
        } catch (Exception $e) {
            $message = "系统错误: " . $e->getMessage();
            $messageType = 'error';
        }
    } else {
        $message = "无效的订单状态值！";
        $messageType = 'error';
    }

    // 重定向回订单列表
    header("Location: index.php?page=order&message={$message}&type={$messageType}");
    exit;
}

// 处理删除采购订单
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $order_id = (int)$_GET['id'];

    try {
        // 先获取采购订单信息用于日志记录
        $sql = "SELECT order_number FROM purchase_orders WHERE order_id = ?";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            $message = "准备查询采购订单的SQL语句失败: " . $conn->error;
            $messageType = 'error';
        } else {
            $stmt->bind_param("i", $order_id);

            if ($stmt->execute()) {
                $result = $stmt->get_result();

                if ($result && $result->num_rows > 0) {
                    $order = $result->fetch_assoc();

                    // 检查该采购订单是否有关联的入库记录
                    $sql = "SELECT COUNT(*) as count FROM purchase_stock WHERE order_id = ?";
                    $checkStmt = $conn->prepare($sql);

                    if ($checkStmt === false) {
                        $message = "准备检查采购订单关联的SQL语句失败: " . $conn->error;
                        $messageType = 'error';
                    } else {
                        $checkStmt->bind_param("i", $order_id);

                        if ($checkStmt->execute()) {
                            $checkResult = $checkStmt->get_result();

                            if ($checkResult && $checkResult->num_rows > 0) {
                                $row = $checkResult->fetch_assoc();

                                if ($row['count'] > 0) {
                                    $message = "无法删除采购订单：该订单已有关联的入库记录！";
                                    $messageType = 'error';
                                } else {
                                    // 删除采购订单商品
                                    $sql = "DELETE FROM purchase_order_items WHERE order_id = ?";
                                    $itemStmt = $conn->prepare($sql);

                                    if ($itemStmt === false) {
                                        $message = "准备删除采购订单商品的SQL语句失败: " . $conn->error;
                                        $messageType = 'error';
                                    } else {
                                        $itemStmt->bind_param("i", $order_id);
                                        $itemStmt->execute();
                                        $itemStmt->close();

                                        // 删除采购对账
                                        $sql = "DELETE FROM purchase_settlements WHERE order_id = ?";
                                        $settlementStmt = $conn->prepare($sql);

                                        if ($settlementStmt === false) {
                                            $message = "准备删除采购对账的SQL语句失败: " . $conn->error;
                                            $messageType = 'error';
                                        } else {
                                            $settlementStmt->bind_param("i", $order_id);
                                            $settlementStmt->execute();
                                            $settlementStmt->close();

                                            // 执行删除采购订单操作
                                            $sql = "DELETE FROM purchase_orders WHERE order_id = ?";
                                            $deleteStmt = $conn->prepare($sql);

                                            if ($deleteStmt === false) {
                                                $message = "准备删除采购订单的SQL语句失败: " . $conn->error;
                                                $messageType = 'error';
                                            } else {
                                                $deleteStmt->bind_param("i", $order_id);

                                                if ($deleteStmt->execute()) {
                                                    $message = "采购订单 {$order['order_number']} 删除成功！";
                                                    $messageType = 'success';

                                                    // 记录操作日志
                                                    $operationDetails = "用户 {$_SESSION['username']} 删除了采购订单: {$order['order_number']}";
                                                    log_operation($_SESSION['user_id'], '删除采购订单', $operationDetails);
                                                } else {
                                                    $message = "删除采购订单失败: " . $deleteStmt->error;
                                                    $messageType = 'error';
                                                }
                                                $deleteStmt->close();
                                            }
                                        }
                                    }
                                }
                            } else {
                                $message = "检查关联入库记录失败";
                                $messageType = 'error';
                            }
                        } else {
                            $message = "执行检查关联入库记录失败: " . $checkStmt->error;
                            $messageType = 'error';
                        }
                        $checkStmt->close();
                    }
                } else {
                    $message = "找不到指定的采购订单！";
                    $messageType = 'error';
                }
            } else {
                $message = "执行查询采购订单失败: " . $stmt->error;
                $messageType = 'error';
            }
            $stmt->close();
        }
    } catch (Exception $e) {
        $message = "系统错误: " . $e->getMessage();
        $messageType = 'error';
    }

    // 重定向到采购订单列表
    header("Location: index.php?page=order&message={$message}&type={$messageType}");
    exit;
}

// 获取要编辑的采购订单信息
$editOrder = null;
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $order_id = (int)$_GET['id'];

    try {
        $sql = "SELECT * FROM purchase_orders WHERE order_id = ?";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            $message = "准备查询采购订单的SQL语句失败: " . $conn->error;
            $messageType = 'error';
        } else {
            $stmt->bind_param("i", $order_id);

            if ($stmt->execute()) {
                $result = $stmt->get_result();

                if ($result && $result->num_rows > 0) {
                    $editOrder = $result->fetch_assoc();
                } else {
                    $message = "找不到指定的采购订单！";
                    $messageType = 'error';
                }
            } else {
                $message = "执行查询采购订单失败: " . $stmt->error;
                $messageType = 'error';
            }
            $stmt->close();
        }
    } catch (Exception $e) {
        $message = "系统错误: " . $e->getMessage();
        $messageType = 'error';
    }
}

// 获取要查看的采购订单详情
$viewOrder = null;
$orderItems = [];
if (isset($_GET['action']) && $_GET['action'] == 'view' && isset($_GET['id'])) {
    $order_id = (int)$_GET['id'];

    try {
        // 获取采购订单信息
        $sql = "SELECT po.*, s.supplier_name 
                FROM purchase_orders po 
                LEFT JOIN suppliers s ON po.supplier_id = s.supplier_id 
                WHERE po.order_id = ?";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            $message = "准备查询采购订单详情的SQL语句失败: " . $conn->error;
            $messageType = 'error';
        } else {
            $stmt->bind_param("i", $order_id);

            if ($stmt->execute()) {
                $result = $stmt->get_result();

                if ($result && $result->num_rows > 0) {
                    $viewOrder = $result->fetch_assoc();

                    // 获取采购订单商品明细
                    $sql = "SELECT * FROM purchase_order_items WHERE order_id = ?";
                    $itemsStmt = $conn->prepare($sql);

                    if ($itemsStmt === false) {
                        $message = "准备查询采购订单商品的SQL语句失败: " . $conn->error;
                        $messageType = 'error';
                    } else {
                        $itemsStmt->bind_param("i", $order_id);

                        if ($itemsStmt->execute()) {
                            $itemsResult = $itemsStmt->get_result();

                            if ($itemsResult) {
                                while ($row = $itemsResult->fetch_assoc()) {
                                    $orderItems[] = $row;
                                }
                            } else {
                                $message = "获取采购订单商品结果集失败";
                                $messageType = 'error';
                            }
                        } else {
                            $message = "执行查询采购订单商品失败: " . $itemsStmt->error;
                            $messageType = 'error';
                        }
                        $itemsStmt->close();
                    }
                } else {
                    $message = "找不到指定的采购订单！";
                    $messageType = 'error';
                }
            } else {
                $message = "执行查询采购订单详情失败: " . $stmt->error;
                $messageType = 'error';
            }
            $stmt->close();
        }
    } catch (Exception $e) {
        $message = "系统错误: " . $e->getMessage();
        $messageType = 'error';
    }
}

// 获取供应商列表（用于表单选择）
$suppliers = [];
try {
    $sql = "SELECT supplier_id, supplier_name FROM suppliers ORDER BY supplier_name";
    $stmt = $conn->prepare($sql);

    if ($stmt === false) {
        $message = "准备查询供应商列表的SQL语句失败: " . $conn->error;
        $messageType = 'error';
    } else {
        if ($stmt->execute()) {
            $result = $stmt->get_result();

            if ($result) {
                while ($row = $result->fetch_assoc()) {
                    $suppliers[] = $row;
                }
            } else {
                $message = "获取供应商列表结果集失败";
                $messageType = 'error';
            }
        } else {
            $message = "执行查询供应商列表失败: " . $stmt->error;
            $messageType = 'error';
        }
        $stmt->close();
    }
} catch (Exception $e) {
    $message = "获取供应商列表失败: " . $e->getMessage();
    $messageType = 'error';
}

// 获取采购订单列表（用于显示在页面上）
try {
    // 处理搜索
    if (!empty($search)) {
        $searchTerm = "%{$search}%";
        $sql = "SELECT po.*, s.supplier_name 
                FROM purchase_orders po 
                LEFT JOIN suppliers s ON po.supplier_id = s.supplier_id 
                WHERE po.order_number LIKE ? OR s.supplier_name LIKE ? 
                ORDER BY po.order_id DESC";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            $message = "准备查询采购订单的SQL语句失败: " . $conn->error;
            $messageType = 'error';
        } else {
            $stmt->bind_param("ss", $searchTerm, $searchTerm);

            if ($stmt->execute()) {
                $result = $stmt->get_result();

                if ($result) {
                    while ($row = $result->fetch_assoc()) {
                        $orders[] = $row;
                    }
                } else {
                    $message = "获取结果集失败: " . $stmt->error;
                    $messageType = 'error';
                }
            } else {
                $message = "执行查询失败: " . $stmt->error;
                $messageType = 'error';
            }
            $stmt->close();
        }
    } else {
        $sql = "SELECT po.*, s.supplier_name 
                FROM purchase_orders po 
                LEFT JOIN suppliers s ON po.supplier_id = s.supplier_id 
                ORDER BY po.order_id DESC";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            $message = "准备查询采购订单的SQL语句失败: " . $conn->error;
            $messageType = 'error';
        } else {
            if ($stmt->execute()) {
                $result = $stmt->get_result();

                if ($result) {
                    while ($row = $result->fetch_assoc()) {
                        $orders[] = $row;
                    }
                } else {
                    $message = "获取结果集失败: " . $stmt->error;
                    $messageType = 'error';
                }
            } else {
                $message = "执行查询失败: " . $stmt->error;
                $messageType = 'error';
            }
            $stmt->close();
        }
    }
} catch (Exception $e) {
    $message = "获取采购订单列表失败: " . $e->getMessage();
    $messageType = 'error';
}

// 处理从URL传来的消息
if (isset($_GET['message']) && isset($_GET['type'])) {
    $message = $_GET['message'];
    $messageType = $_GET['type'];
}

// 生成订单编号
function generateOrderNumber()
{
    return 'PO' . date('YmdHis') . rand(100, 999);
}

// 批量更新订单状态后立即刷新页面
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['batch_action']) && isset($_POST['order_ids'])) {
    $action = $_POST['batch_action'];
    $orderIds = $_POST['order_ids'];
    $updatedCount = 0;
    $failedCount = 0;

    if (!empty($orderIds) && in_array($action, ['approved', 'rejected', 'pending'])) {
        try {
            // 准备SQL语句
            $sql = "UPDATE purchase_orders SET status = ? WHERE order_id = ?";
            $stmt = $conn->prepare($sql);

            if ($stmt === false) {
                $message = "准备批量更新订单状态的SQL语句失败: " . $conn->error;
                $messageType = 'error';
            } else {
                foreach ($orderIds as $orderId) {
                    $stmt->bind_param("si", $action, $orderId);

                    if ($stmt->execute()) {
                        $updatedCount++;
                    } else {
                        $failedCount++;
                    }
                }

                // 记录操作日志
                $actionText = '';
                switch ($action) {
                    case 'approved':
                        $actionText = '审核通过';
                        break;
                    case 'rejected':
                        $actionText = '拒绝';
                        break;
                    case 'pending':
                        $actionText = '待审核';
                        break;
                }

                $operationDetails = "用户 {$_SESSION['username']} 批量{$actionText}了 {$updatedCount} 个采购订单";
                log_operation($_SESSION['user_id'], '批量更新采购订单状态', $operationDetails);

                $message = "成功更新 {$updatedCount} 个订单状态";
                if ($failedCount > 0) {
                    $message .= "，{$failedCount} 个订单更新失败";
                }
                $messageType = ($failedCount > 0) ? 'warning' : 'success';

                // 添加重定向以刷新页面
                header("Location: index.php?page=order&message=" . urlencode($message) . "&type=" . urlencode($messageType));
                exit;
            }
        } catch (Exception $e) {
            $message = "批量更新订单状态失败: " . $e->getMessage();
            $messageType = 'error';
        }
    } else {
        $message = "请选择要处理的订单和有效的操作";
        $messageType = 'error';
    }
}
?>

<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>">
        <?php echo $message; ?>
    </div>
<?php endif; ?>

<!-- 添加或编辑采购订单表单 -->
<?php if (isset($_GET['action']) && ($_GET['action'] == 'add' || ($_GET['action'] == 'edit' && $editOrder))): ?>
    <div class="form-container">
        <h3><?php echo $_GET['action'] == 'add' ? '添加采购订单' : '编辑采购订单'; ?></h3>
        <form action="" method="post">
            <input type="hidden" name="action" value="<?php echo $_GET['action']; ?>">
            <?php if ($_GET['action'] == 'edit'): ?>
                <input type="hidden" name="order_id" value="<?php echo $editOrder['order_id']; ?>">
            <?php endif; ?>

            <div class="form-group">
                <label for="supplier_id">供应商 <span class="required">*</span></label>
                <select id="supplier_id" name="supplier_id" required>
                    <option value="">请选择供应商</option>
                    <?php foreach ($suppliers as $supplier): ?>
                        <option value="<?php echo $supplier['supplier_id']; ?>" <?php echo ($editOrder && $editOrder['supplier_id'] == $supplier['supplier_id']) ? 'selected' : ''; ?>>
                            <?php echo $supplier['supplier_name']; ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="form-group">
                <label for="order_number">订单编号 <span class="required">*</span></label>
                <input type="text" id="order_number" name="order_number" value="<?php echo $editOrder ? $editOrder['order_number'] : generateOrderNumber(); ?>" required>
            </div>

            <div class="form-group">
                <label for="order_date">订单日期 <span class="required">*</span></label>
                <input type="date" id="order_date" name="order_date" value="<?php echo $editOrder ? $editOrder['order_date'] : date('Y-m-d'); ?>" required>
            </div>

            <div class="form-group">
                <label for="total_amount">订单总金额 <span class="required">*</span></label>
                <input type="number" id="total_amount" name="total_amount" step="0.01" min="0.01" value="<?php echo $editOrder ? $editOrder['total_amount'] : ''; ?>" required>
            </div>

            <div class="form-group">
                <label for="status">订单状态 <span class="required">*</span></label>
                <select id="status" name="status" required>
                    <option value="pending" <?php echo ($editOrder && $editOrder['status'] == 'pending') ? 'selected' : ''; ?>>待审核</option>
                    <option value="approved" <?php echo ($editOrder && $editOrder['status'] == 'approved') ? 'selected' : ''; ?>>已审核</option>
                    <option value="rejected" <?php echo ($editOrder && $editOrder['status'] == 'rejected') ? 'selected' : ''; ?>>已拒绝</option>
                </select>
            </div>

            <div class="form-group">
                <button type="submit" class="btn btn-primary">保存</button>
                <a href="index.php?page=order" class="btn btn-secondary">取消</a>
            </div>
        </form>
    </div>
    <!-- 查看采购订单详情 -->
<?php elseif (isset($_GET['action']) && $_GET['action'] == 'view' && $viewOrder): ?>
    <div class="user-details">
        <h3>采购订单详情</h3>
        <div class="detail-group">
            <label>订单ID:</label>
            <span><?php echo $viewOrder['order_id']; ?></span>
        </div>
        <div class="detail-group">
            <label>订单编号:</label>
            <span><?php echo $viewOrder['order_number']; ?></span>
        </div>
        <div class="detail-group">
            <label>供应商:</label>
            <span><?php echo $viewOrder['supplier_name']; ?></span>
        </div>
        <div class="detail-group">
            <label>订单日期:</label>
            <span><?php echo $viewOrder['order_date']; ?></span>
        </div>
        <div class="detail-group">
            <label>订单总金额:</label>
            <span>￥<?php echo number_format($viewOrder['total_amount'], 2); ?></span>
        </div>
        <div class="detail-group">
            <label>订单状态:</label>
            <span>
                <?php
                switch ($viewOrder['status']) {
                    case 'pending':
                        echo '<span class="badge badge-warning">待审核</span>';
                        break;
                    case 'approved':
                        echo '<span class="badge badge-success">已审核</span>';
                        break;
                    case 'rejected':
                        echo '<span class="badge badge-danger">已拒绝</span>';
                        break;
                    default:
                        echo $viewOrder['status'];
                }
                ?>
            </span>
        </div>
        <div class="detail-group">
            <label>创建时间:</label>
            <span><?php echo $viewOrder['created_at']; ?></span>
        </div>
        <div class="detail-group">
            <label>最后更新:</label>
            <span><?php echo $viewOrder['updated_at']; ?></span>
        </div>

        <h4>订单商品明细</h4>
        <?php if (count($orderItems) > 0): ?>
            <table class="data-table order-items-table">
                <thead>
                    <tr>
                        <th>商品名称</th>
                        <th>数量</th>
                        <th>单价</th>
                        <th>总价</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($orderItems as $item): ?>
                        <tr>
                            <td><?php echo $item['product_name']; ?></td>
                            <td><?php echo $item['quantity']; ?></td>
                            <td>￥<?php echo number_format($item['unit_price'], 2); ?></td>
                            <td>￥<?php echo number_format($item['total_price'], 2); ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        <?php else: ?>
            <p>暂无商品明细</p>
        <?php endif; ?>

        <div class="detail-actions">
            <a href="index.php?page=order" class="btn btn-secondary">返回订单列表</a>
            <a href="index.php?page=order&action=edit&id=<?php echo $viewOrder['order_id']; ?>" class="btn btn-primary">编辑订单</a>
        </div>
    </div>

    <style>
        /* 订单详情页面样式 */
        .user-details {
            background-color: #f9f9f9;
            padding: 20px;
            border-radius: 5px;
            margin-bottom: 20px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            border: 1px solid #e0e0e0;
        }

        .user-details h3,
        .user-details h4 {
            margin-top: 0;
            margin-bottom: 20px;
            color: #333;
            border-bottom: 1px solid #ddd;
            padding-bottom: 10px;
            font-size: 1.2em;
        }

        .user-details h4 {
            margin-top: 20px;
            font-size: 1.1em;
        }

        .detail-group {
            margin-bottom: 12px;
            display: flex;
            align-items: center;
            border-bottom: 1px dashed #eee;
            padding-bottom: 8px;
        }

        .detail-group:last-of-type {
            border-bottom: none;
        }

        .detail-group label {
            font-weight: bold;
            width: 120px;
            color: #555;
            flex-shrink: 0;
        }

        .detail-group span {
            flex-grow: 1;
            color: #333;
        }

        .order-items-table {
            margin-bottom: 20px;
            width: 100%;
        }

        .detail-actions {
            margin-top: 20px;
            padding-top: 15px;
            border-top: 1px solid #ddd;
            display: flex;
            gap: 10px;
        }

        .detail-actions .btn {
            padding: 8px 16px;
            text-decoration: none;
            border-radius: 4px;
            font-weight: normal;
            text-align: center;
        }

        .badge {
            display: inline-block;
            padding: 0.25em 0.6em;
            font-size: 75%;
            font-weight: 700;
            line-height: 1;
            text-align: center;
            white-space: nowrap;
            vertical-align: baseline;
            border-radius: 0.25rem;
        }

        .badge-warning {
            color: #212529;
            background-color: #ffc107;
        }

        .badge-success {
            color: #fff;
            background-color: #28a745;
        }

        .badge-danger {
            color: #fff;
            background-color: #dc3545;
        }
    </style>
    <!-- 采购订单列表 -->
<?php else: ?>
    <div class="module-tools">
        <div class="tool-left">
            <a href="index.php?page=order&action=add" class="btn btn-primary">新增采购订单</a>

            <!-- 批量操作部分 -->
            <form method="post" id="batch-form" class="batch-form">
                <div class="batch-actions">
                    <select name="batch_action" class="form-control">
                        <option value="">批量操作...</option>
                        <option value="approved">批量审核通过</option>
                        <option value="rejected">批量拒绝</option>
                        <option value="pending">批量设为待审核</option>
                    </select>
                    <button type="submit" class="btn btn-primary" onclick="return confirm('确定要执行所选操作吗？')">应用</button>
                </div>
            </form>
        </div>
        <div class="tool-right">
            <form action="index.php" method="get" class="search-form">
                <input type="hidden" name="page" value="order">
                <div class="search-group">
                    <input type="text" name="keyword" placeholder="订单编号/供应商" class="search-input" value="<?php echo htmlspecialchars($search); ?>">
                    <button type="submit" class="btn btn-primary">搜索</button>
                    <?php if (!empty($search)): ?>
                        <a href="index.php?page=order" class="btn btn-secondary">清除</a>
                    <?php endif; ?>
                </div>
            </form>
        </div>
    </div>

    <div class="data-wrapper">
        <table class="data-table">
            <thead>
                <tr>
                    <th><input type="checkbox" id="select-all"></th>
                    <th>ID</th>
                    <th>订单编号</th>
                    <th>供应商</th>
                    <th>订单日期</th>
                    <th>订单金额</th>
                    <th>订单状态</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php if (count($orders) > 0): ?>
                    <?php foreach ($orders as $order): ?>
                        <tr>
                            <td><input type="checkbox" name="order_ids[]" value="<?php echo $order['order_id']; ?>" class="order-checkbox" form="batch-form"></td>
                            <td><?php echo $order['order_id']; ?></td>
                            <td><?php echo $order['order_number']; ?></td>
                            <td><?php echo $order['supplier_name']; ?></td>
                            <td><?php echo $order['order_date']; ?></td>
                            <td>￥<?php echo number_format($order['total_amount'], 2); ?></td>
                            <td>
                                <?php
                                switch ($order['status']) {
                                    case 'pending':
                                        echo '<span class="badge badge-warning">待审核</span> ';
                                        echo '<a href="javascript:void(0);" onclick="if(confirm(\'确定要将订单状态更新为已审核吗？\')) window.location.href=\'index.php?page=order&action=update_status&id=' . $order['order_id'] . '&status=approved\';" class="btn btn-xs btn-success" title="一键审核通过"><i class="fa fa-check"></i></a>';
                                        echo ' <a href="javascript:void(0);" onclick="if(confirm(\'确定要将订单状态更新为已拒绝吗？\')) window.location.href=\'index.php?page=order&action=update_status&id=' . $order['order_id'] . '&status=rejected\';" class="btn btn-xs btn-danger" title="一键拒绝"><i class="fa fa-times"></i></a>';
                                        break;
                                    case 'approved':
                                        echo '<span class="badge badge-success">已审核</span> ';
                                        echo '<a href="javascript:void(0);" onclick="if(confirm(\'确定要将订单状态撤回到待审核吗？\')) window.location.href=\'index.php?page=order&action=update_status&id=' . $order['order_id'] . '&status=pending\';" class="btn btn-xs btn-warning" title="撤销审核"><i class="fa fa-undo"></i></a>';
                                        break;
                                    case 'rejected':
                                        echo '<span class="badge badge-danger">已拒绝</span> ';
                                        echo '<a href="javascript:void(0);" onclick="if(confirm(\'确定要将订单状态撤回到待审核吗？\')) window.location.href=\'index.php?page=order&action=update_status&id=' . $order['order_id'] . '&status=pending\';" class="btn btn-xs btn-warning" title="撤销拒绝"><i class="fa fa-undo"></i></a>';
                                        break;
                                    default:
                                        echo $order['status'];
                                }
                                ?>
                            </td>
                            <td class="actions">
                                <a href="index.php?page=order&action=view&id=<?php echo $order['order_id']; ?>" class="btn btn-secondary btn-sm">查看</a>
                                <a href="index.php?page=order&action=edit&id=<?php echo $order['order_id']; ?>" class="btn btn-primary btn-sm">编辑</a>
                                <a href="index.php?page=order&action=delete&id=<?php echo $order['order_id']; ?>" class="btn btn-danger btn-sm" onclick="return confirm('确定要删除此采购订单吗？')">删除</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="8" class="text-center">暂无采购订单数据</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <script>
        // 全选/取消全选
        document.getElementById('select-all').addEventListener('change', function() {
            var checkboxes = document.getElementsByClassName('order-checkbox');
            for (var i = 0; i < checkboxes.length; i++) {
                checkboxes[i].checked = this.checked;
            }
        });

        // 如果所有复选框都被勾选，则"全选"复选框也应该被勾选
        var orderCheckboxes = document.getElementsByClassName('order-checkbox');
        for (var i = 0; i < orderCheckboxes.length; i++) {
            orderCheckboxes[i].addEventListener('change', function() {
                var allChecked = true;
                for (var j = 0; j < orderCheckboxes.length; j++) {
                    if (!orderCheckboxes[j].checked) {
                        allChecked = false;
                        break;
                    }
                }
                document.getElementById('select-all').checked = allChecked;
            });
        }
    </script>

    <style>
        /* 订单列表页面样式 */
        .badge {
            display: inline-block;
            padding: 0.25em 0.6em;
            font-size: 75%;
            font-weight: 700;
            line-height: 1;
            text-align: center;
            white-space: nowrap;
            vertical-align: baseline;
            border-radius: 0.25rem;
        }

        .badge-warning {
            color: #212529;
            background-color: #ffc107;
        }

        .badge-success {
            color: #fff;
            background-color: #28a745;
        }

        .badge-danger {
            color: #fff;
            background-color: #dc3545;
        }

        /* 快速操作按钮样式 */
        .btn-xs {
            padding: 0.1rem 0.25rem;
            font-size: 0.675rem;
            line-height: 1.5;
            border-radius: 0.2rem;
        }

        td .btn-xs {
            margin-right: 2px;
        }

        td .btn-xs i {
            font-size: 10px;
        }

        td.actions {
            white-space: nowrap;
        }

        /* 批量操作和搜索框样式 */
        .module-tools {
            display: flex;
            justify-content: space-between;
            margin-bottom: 15px;
            flex-wrap: wrap;
        }

        .tool-left,
        .tool-right {
            display: flex;
            align-items: center;
            gap: 10px;
            margin-bottom: 10px;
        }

        .batch-form {
            display: inline-block;
            margin-left: 15px;
        }

        .batch-actions {
            display: flex;
            gap: 10px;
            align-items: center;
        }

        .batch-actions select {
            width: auto;
            display: inline-block;
            padding: 6px 12px;
            font-size: 14px;
            font-weight: 400;
            line-height: 1.5;
            color: #495057;
            background-color: #fff;
            background-clip: padding-box;
            border: 1px solid #ced4da;
            border-radius: 0.25rem;
            transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
        }

        .data-table th:first-child,
        .data-table td:first-child {
            width: 40px;
            text-align: center;
        }

        .search-group {
            display: flex;
            align-items: center;
        }

        .search-input {
            padding: 6px 12px;
            font-size: 14px;
            line-height: 1.5;
            color: #495057;
            background-color: #fff;
            background-clip: padding-box;
            border: 1px solid #ced4da;
            border-radius: 0.25rem 0 0 0.25rem;
            transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
        }

        .search-group .btn {
            border-radius: 0 0.25rem 0.25rem 0;
            margin-left: -1px;
        }
    </style>
<?php endif; ?>