<?php
// 防止直接访问
if (!defined('IN_SYSTEM')) {
    define('IN_SYSTEM', true);
}

// 确保bills变量始终是数组
if (!isset($bills) || !is_array($bills)) {
    $bills = [];
}

// 确保totalRecords变量始终有值
if (!isset($totalRecords)) {
    $totalRecords = 0;
}
?>
<div class="bill-header">
    <h3>自定义账单管理</h3>
    <p>创建、管理和跟踪各种类型的收支账单。</p>
    <a href="index.php?page=custom_bill&action=add" class="btn btn-primary">
        <i class="fas fa-plus"></i> 新增账单
    </a>
</div>

<!-- 消息提示 -->
<?php if (isset($message) && isset($messageType)): ?>
    <div class="alert alert-<?php echo $messageType == 'error' ? 'danger' : $messageType; ?> alert-dismissible fade show" role="alert">
        <?php echo $message; ?>
        <button type="button" class="close" data-dismiss="alert" aria-label="Close">
            <span aria-hidden="true">&times;</span>
        </button>
    </div>
<?php endif; ?>

<!-- 简化的搜索表单 -->
<div class="search-form">
    <form action="index.php" method="GET" class="form-row">
        <input type="hidden" name="page" value="custom_bill">
        <div class="form-group col-md-3">
            <input type="text" class="form-control" name="search" placeholder="关键词搜索" value="<?php echo htmlspecialchars($search); ?>">
        </div>
        <div class="form-group col-md-2">
            <select class="form-control" name="bill_type">
                <option value="">全部类型</option>
                <option value="income" <?php echo $bill_type == 'income' ? 'selected' : ''; ?>>收入</option>
                <option value="expense" <?php echo $bill_type == 'expense' ? 'selected' : ''; ?>>支出</option>
            </select>
        </div>
        <div class="form-group col-md-3">
            <select class="form-control" name="category">
                <option value="">全部分类</option>
                <?php foreach ($categories as $cat): ?>
                    <option value="<?php echo htmlspecialchars($cat); ?>" <?php echo $category == $cat ? 'selected' : ''; ?>>
                        <?php echo htmlspecialchars($cat); ?>
                    </option>
                <?php endforeach; ?>
            </select>
        </div>
        <div class="form-group col-md-4">
            <button type="submit" class="btn btn-primary">
                <i class="fas fa-search"></i> 搜索
            </button>
            <a href="index.php?page=custom_bill" class="btn btn-secondary ml-2">
                <i class="fas fa-sync"></i> 重置
            </a>
        </div>
    </form>
</div>

<!-- 统计信息 -->
<?php
// 收入总额
$incomeSql = "SELECT SUM(amount) as total FROM custom_bills WHERE bill_type = 'income'";
$incomeResult = $conn->query($incomeSql);
$incomeTotal = $incomeResult && ($row = $incomeResult->fetch_assoc()) ? $row['total'] : 0;

// 支出总额
$expenseSql = "SELECT SUM(amount) as total FROM custom_bills WHERE bill_type = 'expense'";
$expenseResult = $conn->query($expenseSql);
$expenseTotal = $expenseResult && ($row = $expenseResult->fetch_assoc()) ? $row['total'] : 0;

// 当前搜索条件下的总额
if (!empty($whereClause)) {
    $searchIncomeSql = "SELECT SUM(amount) as total FROM custom_bills " . str_replace("WHERE", "WHERE bill_type = 'income' AND ", $whereClause);
    $searchExpenseSql = "SELECT SUM(amount) as total FROM custom_bills " . str_replace("WHERE", "WHERE bill_type = 'expense' AND ", $whereClause);

    if (!empty($params)) {
        // 收入统计
        $searchIncomeStmt = $conn->prepare($searchIncomeSql);
        $incomeTypes = $types;
        $incomeParams = $params;
        $searchIncomeStmt->bind_param($incomeTypes, ...$incomeParams);
        $searchIncomeStmt->execute();
        $searchIncomeResult = $searchIncomeStmt->get_result();
        $searchIncomeTotal = $searchIncomeResult->fetch_assoc()['total'] ?: 0;
        $searchIncomeStmt->close();

        // 支出统计
        $searchExpenseStmt = $conn->prepare($searchExpenseSql);
        $expenseTypes = $types;
        $expenseParams = $params;
        $searchExpenseStmt->bind_param($expenseTypes, ...$expenseParams);
        $searchExpenseStmt->execute();
        $searchExpenseResult = $searchExpenseStmt->get_result();
        $searchExpenseTotal = $searchExpenseResult->fetch_assoc()['total'] ?: 0;
        $searchExpenseStmt->close();
    } else {
        $searchIncomeResult = $conn->query($searchIncomeSql);
        $searchIncomeTotal = $searchIncomeResult && ($row = $searchIncomeResult->fetch_assoc()) ? $row['total'] : 0;

        $searchExpenseResult = $conn->query($searchExpenseSql);
        $searchExpenseTotal = $searchExpenseResult && ($row = $searchExpenseResult->fetch_assoc()) ? $row['total'] : 0;
    }
} else {
    $searchIncomeTotal = $incomeTotal;
    $searchExpenseTotal = $expenseTotal;
}

// 计算净收入
$netTotal = $incomeTotal - $expenseTotal;
$searchNetTotal = $searchIncomeTotal - $searchExpenseTotal;

// 计算当前视图中的收入和支出账单数量
$incomeCount = 0;
$expenseCount = 0;
foreach ($bills as $bill) {
    if ($bill['bill_type'] == 'income') {
        $incomeCount++;
    } elseif ($bill['bill_type'] == 'expense') {
        $expenseCount++;
    }
}
?>

<!-- 统计概览 -->
<div class="stats-overview">
    <div class="stat-item income">
        <div class="stat-title">总收入</div>
        <div class="stat-value">¥ <?php echo number_format($incomeTotal, 2); ?></div>
        <?php if (isset($searchIncomeTotal) && $searchIncomeTotal != $incomeTotal): ?>
            <div class="stat-filter">当前筛选: ¥ <?php echo number_format($searchIncomeTotal, 2); ?></div>
        <?php endif; ?>
    </div>
    <div class="stat-item expense">
        <div class="stat-title">总支出</div>
        <div class="stat-value">¥ <?php echo number_format($expenseTotal, 2); ?></div>
        <?php if (isset($searchExpenseTotal) && $searchExpenseTotal != $expenseTotal): ?>
            <div class="stat-filter">当前筛选: ¥ <?php echo number_format($searchExpenseTotal, 2); ?></div>
        <?php endif; ?>
    </div>
    <div class="stat-item <?php echo $netTotal >= 0 ? 'net-positive' : 'net-negative'; ?>">
        <div class="stat-title">净收入</div>
        <div class="stat-value">¥ <?php echo number_format($netTotal, 2); ?></div>
        <?php if (isset($searchNetTotal) && $searchNetTotal != $netTotal): ?>
            <div class="stat-filter">当前筛选: ¥ <?php echo number_format($searchNetTotal, 2); ?></div>
        <?php endif; ?>
    </div>
    <div class="stat-item count">
        <div class="stat-title">账单总数</div>
        <div class="stat-value"><?php echo isset($totalRecords) ? $totalRecords : '0'; ?></div>
        <div class="stat-filter">
            收入: <?php echo $incomeCount; ?> | 支出: <?php echo $expenseCount; ?>
        </div>
    </div>
</div>

<!-- 账单列表 -->
<div class="data-wrapper">
    <h4 class="data-title">账单列表 (<?php echo $totalRecords; ?>条记录)</h4>

    <?php if (empty($bills)): ?>
        <div class="alert alert-info">
            暂无账单记录。 <a href="index.php?page=custom_bill&action=add" class="alert-link">点击创建第一条账单</a>
        </div>
    <?php else: ?>
        <table class="data-table">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>账单类型</th>
                    <th>日期</th>
                    <th>描述</th>
                    <th>金额 (¥)</th>
                    <th>支付方式</th>
                    <th>客户</th>
                    <th>分类</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($bills as $bill): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($bill['bill_id']); ?></td>
                        <td>
                            <span class="badge badge-<?php echo getBillTypeBadgeClass($bill['bill_type']); ?>">
                                <?php echo getBillTypeName($bill['bill_type']); ?>
                            </span>
                        </td>
                        <td><?php echo htmlspecialchars($bill['transaction_date']); ?></td>
                        <td><?php echo htmlspecialchars($bill['description']); ?></td>
                        <td class="<?php echo $bill['bill_type'] == 'income' ? 'text-success' : 'text-danger'; ?> font-weight-bold">
                            <?php echo number_format($bill['amount'], 2); ?>
                        </td>
                        <td><?php echo htmlspecialchars($bill['payment_method']); ?></td>
                        <td>
                            <?php if (!empty($bill['related_customer_id']) && !empty($bill['customer_name'])): ?>
                                <a href="index.php?page=customer&action=view&id=<?php echo $bill['related_customer_id']; ?>">
                                    <?php echo htmlspecialchars($bill['customer_name']); ?>
                                </a>
                            <?php else: ?>
                                <span class="text-muted">--</span>
                            <?php endif; ?>
                        </td>
                        <td><?php echo !empty($bill['category']) ? htmlspecialchars($bill['category']) : '<span class="text-muted">--</span>'; ?></td>
                        <td>
                            <a href="index.php?page=custom_bill&action=view&id=<?php echo $bill['bill_id']; ?>"
                                class="btn btn-sm btn-info">
                                <i class="fas fa-eye"></i> 查看
                            </a>
                            <a href="index.php?page=custom_bill&action=edit&id=<?php echo $bill['bill_id']; ?>"
                                class="btn btn-sm btn-primary">
                                <i class="fas fa-edit"></i> 编辑
                            </a>
                            <a href="javascript:void(0);" onclick="confirmDelete(<?php echo $bill['bill_id']; ?>, '<?php echo htmlspecialchars($bill['description']); ?>')"
                                class="btn btn-sm btn-danger">
                                <i class="fas fa-trash"></i> 删除
                            </a>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>

        <!-- 分页控件 -->
        <?php if (isset($totalPages) && $totalPages > 1): ?>
            <div class="pagination">
                <?php if ($page > 1): ?>
                    <a href="index.php?page=custom_bill&listpage=1&search=<?php echo urlencode($search); ?>&bill_type=<?php echo urlencode($bill_type); ?>&category=<?php echo urlencode($category); ?>" class="pagination-item">首页</a>
                    <a href="index.php?page=custom_bill&listpage=<?php echo $page - 1; ?>&search=<?php echo urlencode($search); ?>&bill_type=<?php echo urlencode($bill_type); ?>&category=<?php echo urlencode($category); ?>" class="pagination-item">上一页</a>
                <?php endif; ?>

                <?php
                $startPage = max(1, $page - 2);
                $endPage = min($totalPages, $page + 2);

                for ($i = $startPage; $i <= $endPage; $i++):
                ?>
                    <a href="index.php?page=custom_bill&listpage=<?php echo $i; ?>&search=<?php echo urlencode($search); ?>&bill_type=<?php echo urlencode($bill_type); ?>&category=<?php echo urlencode($category); ?>" class="pagination-item <?php echo $i == $page ? 'active' : ''; ?>"><?php echo $i; ?></a>
                <?php endfor; ?>

                <?php if ($page < $totalPages): ?>
                    <a href="index.php?page=custom_bill&listpage=<?php echo $page + 1; ?>&search=<?php echo urlencode($search); ?>&bill_type=<?php echo urlencode($bill_type); ?>&category=<?php echo urlencode($category); ?>" class="pagination-item">下一页</a>
                    <a href="index.php?page=custom_bill&listpage=<?php echo $totalPages; ?>&search=<?php echo urlencode($search); ?>&bill_type=<?php echo urlencode($bill_type); ?>&category=<?php echo urlencode($category); ?>" class="pagination-item">末页</a>
                <?php endif; ?>
            </div>
        <?php endif; ?>
    <?php endif; ?>
</div>

<script type="text/javascript">
    // 删除确认功能
    function confirmDelete(billId, description) {
        if (confirm('确定要删除账单 "' + description + '" 吗？此操作不可恢复！')) {
            window.location.href = 'index.php?page=custom_bill&action=delete&id=' + billId;
        }
    }
</script>

<style>
    /* 表头样式 */
    .bill-header {
        margin-bottom: 20px;
        border-left: 4px solid #2196F3;
        padding-left: 15px;
    }

    .bill-header h3 {
        margin-bottom: 10px;
        font-size: 20px;
    }

    /* 搜索表单样式 */
    .search-form {
        background-color: #f9f9f9;
        padding: 15px;
        border-radius: 5px;
        margin-bottom: 20px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
    }

    .search-form .form-row {
        display: flex;
        align-items: center;
        margin-left: 0;
        margin-right: 0;
    }

    .search-form .form-group {
        margin-bottom: 0;
        padding-right: 10px;
    }

    .search-form .btn {
        margin-right: 5px;
    }

    /* 统计概览样式 */
    .stats-overview {
        display: flex;
        justify-content: space-between;
        margin-bottom: 20px;
        flex-wrap: wrap;
    }

    .stat-item {
        flex: 1;
        min-width: 200px;
        background-color: #f9f9f9;
        border-radius: 5px;
        padding: 15px;
        margin-right: 10px;
        margin-bottom: 10px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
    }

    .stat-item:last-child {
        margin-right: 0;
    }

    .stat-title {
        font-size: 14px;
        color: #666;
        margin-bottom: 5px;
    }

    .stat-value {
        font-size: 24px;
        font-weight: bold;
        margin-bottom: 5px;
    }

    .stat-filter {
        font-size: 12px;
        color: #666;
    }

    /* 各种统计类型的颜色 */
    .income {
        border-left: 5px solid #28a745;
    }

    .expense {
        border-left: 5px solid #dc3545;
    }

    .net-positive {
        border-left: 5px solid #28a745;
    }

    .net-negative {
        border-left: 5px solid #dc3545;
    }

    .count {
        border-left: 5px solid #17a2b8;
    }

    /* 数据列表样式 */
    .data-wrapper {
        background-color: #fff;
        padding: 20px;
        border-radius: 5px;
        margin-bottom: 20px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
    }

    .data-title {
        margin-bottom: 15px;
        color: #333;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
        margin-bottom: 20px;
    }

    .data-table th,
    .data-table td {
        padding: 8px 12px;
        text-align: left;
        border-bottom: 1px solid #ddd;
    }

    .data-table thead th {
        background-color: #f5f5f5;
        font-weight: bold;
    }

    .data-table tbody tr:hover {
        background-color: #f9f9f9;
    }

    /* 分页样式 */
    .pagination {
        display: flex;
        justify-content: center;
        margin-top: 20px;
    }

    .pagination-item {
        display: inline-block;
        padding: 5px 10px;
        margin: 0 3px;
        background-color: #f5f5f5;
        border-radius: 3px;
        color: #333;
        text-decoration: none;
    }

    .pagination-item:hover {
        background-color: #e0e0e0;
    }

    .pagination-item.active {
        background-color: #007bff;
        color: #fff;
    }

    /* 徽章样式 */
    .badge {
        display: inline-block;
        padding: 3px 7px;
        font-size: 12px;
        font-weight: bold;
        line-height: 1;
        text-align: center;
        white-space: nowrap;
        vertical-align: baseline;
        border-radius: 10px;
        color: white;
    }

    .badge-success {
        background-color: #28a745;
    }

    .badge-danger {
        background-color: #dc3545;
    }

    .badge-secondary {
        background-color: #6c757d;
    }

    /* 按钮样式保持一致 */
    .btn-sm {
        padding: 3px 6px;
        font-size: 12px;
        margin: 0 2px;
    }
</style>