<?php
// 添加调试信息
error_log("正在加载invoice_form.php, action=" . $action);

// 防止直接访问
defined('IN_SYSTEM') || die('禁止访问');

// 获取操作类型
$action = isset($_GET['action']) ? $_GET['action'] : 'add';
$isEdit = $action === 'edit';
$invoiceId = isset($_GET['id']) ? (int) $_GET['id'] : 0;

// 检查是否是提交成功后的访问
$isSuccess = isset($_GET['success']) && $_GET['success'] == 1;
$successMessage = '';
if ($isSuccess) {
    if ($isEdit) {
        $successMessage = '销售开单更新成功';
    } else {
        $successMessage = '销售开单创建成功';
    }
}

// 记录表单参数
error_log("Invoice form参数: action=$action, isEdit=$isEdit, invoiceId=$invoiceId, isSuccess=$isSuccess");

// 获取表单数据
$invoice = [];
$invoiceItems = [];

// 如果是编辑模式，获取发票信息
if ($isEdit && $invoiceId > 0) {
    // 获取发票基本信息
    $invoiceSql = "SELECT * FROM sales_invoices WHERE invoice_id = ?";
    $stmt = $conn->prepare($invoiceSql);
    if ($stmt) {
        $stmt->bind_param("i", $invoiceId);
        $stmt->execute();
        $invoiceResult = $stmt->get_result();
        if ($invoiceResult && $invoiceResult->num_rows > 0) {
            $invoice = $invoiceResult->fetch_assoc();
        }
        $stmt->close();
    }

    // 获取发票明细
    $itemsSql = "SELECT * FROM sales_invoice_items WHERE invoice_id = ?";
    $stmt = $conn->prepare($itemsSql);
    if ($stmt) {
        $stmt->bind_param("i", $invoiceId);
        $stmt->execute();
        $itemsResult = $stmt->get_result();
        while ($itemsResult && $row = $itemsResult->fetch_assoc()) {
            $invoiceItems[] = $row;
        }
        $stmt->close();
    }

    // 对于每个发票明细项，获取所有可用的批次
    foreach ($invoiceItems as &$item) {
        // 添加商品信息（用于显示单位）
        $productSql = "SELECT unit FROM products WHERE product_id = ?";
        $stmt = $conn->prepare($productSql);
        if ($stmt) {
            $stmt->bind_param("i", $item['product_id']);
            $stmt->execute();
            $productResult = $stmt->get_result();
            if ($productResult && $row = $productResult->fetch_assoc()) {
                $item['unit'] = $row['unit'];
            }
            $stmt->close();
        }

        // 获取商品当前仓库信息
        $warehouseSql = "SELECT warehouse_name FROM warehouses WHERE warehouse_id = ?";
        $stmt = $conn->prepare($warehouseSql);
        if ($stmt) {
            $stmt->bind_param("i", $item['warehouse_id']);
            $stmt->execute();
            $warehouseResult = $stmt->get_result();
            if ($warehouseResult && $row = $warehouseResult->fetch_assoc()) {
                $item['warehouse_name'] = $row['warehouse_name'];
            }
            $stmt->close();
        }

        // 获取该商品在所有仓库中的批次信息
        $batchSql = "SELECT pb.batch_id, pb.batch_number, pb.production_date, pb.expiration_date, i.quantity
                    FROM product_batches pb
                    JOIN inventory i ON pb.batch_id = i.batch_id
                    WHERE i.product_id = ? AND i.warehouse_id = ? AND (i.quantity > 0 OR pb.batch_id = ?)";
        $stmt = $conn->prepare($batchSql);
        if ($stmt) {
            $stmt->bind_param("iii", $item['product_id'], $item['warehouse_id'], $item['batch_id']);
            $stmt->execute();
            $batchResult = $stmt->get_result();
            $item['batches'] = [];
            while ($batchResult && $row = $batchResult->fetch_assoc()) {
                $item['batches'][] = $row;
            }
            $stmt->close();
        }

        // 记录获取到的批次信息
        error_log("为商品ID: " . $item['product_id'] . " 在仓库ID: " . $item['warehouse_id'] . " 找到 " . count($item['batches']) . " 个批次");
    }
}

// 获取客户列表
$customerSql = "SELECT customer_id, customer_name FROM customers ORDER BY customer_name";
$customerResult = $conn->query($customerSql);
$customers = [];
while ($customerResult && $row = $customerResult->fetch_assoc()) {
    $customers[] = $row;
}

// 获取仓库列表
$warehouseSql = "SELECT warehouse_id, warehouse_name FROM warehouses ORDER BY warehouse_name";
$warehouseResult = $conn->query($warehouseSql);
$warehouses = [];
while ($warehouseResult && $row = $warehouseResult->fetch_assoc()) {
    $warehouses[] = $row;
}

// // 获取商品列表
// $productSql = "SELECT product_id, product_name, unit_price, unit FROM products WHERE status = 'active' ORDER BY product_name";
// $productResult = $conn->query($productSql);
// $products = [];
// while ($productResult && $row = $productResult->fetch_assoc()) {
//     $products[] = $row;
// }
// 获取商品列表 - 包含单位信息
$productSql = "SELECT product_id, product_name, unit_price, unit FROM products ORDER BY product_name";
$productResult = $conn->query($productSql);
$products = [];
while ($productResult && $row = $productResult->fetch_assoc()) {
    $products[] = $row;
}
// 获取销售订单列表
$orderSql = "SELECT o.order_id, o.order_number, o.customer_id, c.customer_name 
            FROM sales_orders o 
            JOIN customers c ON o.customer_id = c.customer_id 
            WHERE o.order_status IN ('processing', 'shipped') 
            ORDER BY o.order_date DESC";
$orderResult = $conn->query($orderSql);
$orders = [];
while ($orderResult && $row = $orderResult->fetch_assoc()) {
    $orders[] = $row;
}
?>

<!-- 加载CSS和JS -->
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
<script src="https://cdn.jsdelivr.net/npm/jquery@3.6.0/dist/jquery.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>

<style>
    /* 自定义样式，调整商品选择宽度 */
    .product-select-container {
        min-width: 300px;
        width: 100%;
    }

    .select2-container {
        width: 100% !important;
    }

    .product-column {
        min-width: 300px;
        width: 35%;
    }

    .warehouse-column {
        width: 15%;
    }

    .batch-column {
        width: 15%;
    }

    .unit-column,
    .price-column,
    .quantity-column,
    .discount-column {
        width: 10%;
    }

    .subtotal-column {
        width: 12%;
    }

    .remark-column {
        width: 15%;
    }

    .action-column {
        width: 5%;
    }
</style>

<!-- 显示消息 -->
<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<?php if (!empty($successMessage)): ?>
    <div class="alert alert-success">
        <?php echo $successMessage; ?>
        <div class="mt-3">
            <a href="index.php?page=invoice" class="btn btn-primary">返回列表</a>
            <?php if ($action === 'add' && !empty($invoiceId)): ?>
                <a href="index.php?page=invoice&action=edit&id=<?php echo $invoiceId; ?>" class="btn btn-secondary">继续编辑</a>
            <?php endif; ?>
        </div>
    </div>
<?php endif; ?>

<div class="module-tools">
    <div class="tool-left">
        <a href="index.php?page=invoice" class="btn btn-secondary">返回列表</a>
    </div>
</div>

<div class="data-wrapper">
    <h4 class="data-title"><?php echo $isEdit ? '编辑销售开单' : '创建销售开单'; ?></h4>

    <form id="invoiceForm" action="index.php?page=invoice&action=<?php echo $isEdit ? 'update' : 'add'; ?>" method="post" class="form-horizontal">
        <!-- 添加调试用隐藏字段 -->
        <input type="hidden" name="_form_debug" value="1">
        <!-- 确保invoice_id字段始终存在并被正确赋值 -->
        <input type="hidden" name="invoice_id" value="<?php echo $isEdit ? $invoiceId : ''; ?>">
        <input type="hidden" name="total_amount" id="total_amount" value="<?php echo $invoice['total_amount'] ?? 0; ?>">

        <!-- 添加必要的隐藏字段 -->
        <input type="hidden" name="invoice_number" value="<?php echo isset($invoice['invoice_number']) ? $invoice['invoice_number'] : generateInvoiceNumber(); ?>">

        <div class="form-group">
            <label class="form-label">发票类型</label>
            <div class="form-input">
                <select id="invoice_type" name="invoice_type" class="form-control" required>
                    <option value="retail" <?php echo (isset($invoice['invoice_type']) && $invoice['invoice_type'] == 'retail') ? 'selected' : ''; ?>>零售</option>
                    <option value="wholesale" <?php echo (isset($invoice['invoice_type']) && $invoice['invoice_type'] == 'wholesale') ? 'selected' : ''; ?>>批发</option>
                </select>
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">发票状态</label>
            <div class="form-input">
                <select name="invoice_status" class="form-control" required>
                    <option value="draft" <?php echo (isset($invoice['invoice_status']) && $invoice['invoice_status'] == 'draft') ? 'selected' : ''; ?>>草稿</option>
                    <option value="issued" <?php echo (isset($invoice['invoice_status']) && $invoice['invoice_status'] == 'issued') ? 'selected' : ''; ?>>已开票</option>
                    <option value="cancelled" <?php echo (isset($invoice['invoice_status']) && $invoice['invoice_status'] == 'cancelled') ? 'selected' : ''; ?>>已取消</option>
                </select>
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">付款状态</label>
            <div class="form-input">
                <select id="paymentStatus" name="payment_status" class="form-control" required>
                    <option value="unpaid" <?php echo (isset($invoice['payment_status']) && $invoice['payment_status'] == 'unpaid') ? 'selected' : ''; ?>>未支付</option>
                    <option value="partial" <?php echo (isset($invoice['payment_status']) && $invoice['payment_status'] == 'partial') ? 'selected' : ''; ?>>部分支付</option>
                    <option value="paid" <?php echo (isset($invoice['payment_status']) && $invoice['payment_status'] == 'paid') ? 'selected' : ''; ?>>已支付</option>
                </select>
            </div>
        </div>

        <!-- 已付金额字段 - 根据付款状态动态显示 -->
        <div class="form-group payment-amount-group" style="display: <?php echo (isset($invoice['payment_status']) && ($invoice['payment_status'] == 'partial' || $invoice['payment_status'] == 'paid')) ? 'block' : 'none'; ?>;">
            <label class="form-label">已付金额(元)</label>
            <div class="form-input">
                <input type="number" step="0.01" id="paidAmount" name="paid_amount" class="form-control"
                    value="<?php echo isset($invoice['paid_amount']) ? $invoice['paid_amount'] : '0.00'; ?>">
            </div>
        </div>

        <div class="form-group" id="order_id_group" style="display: <?php echo (isset($invoice['invoice_type']) && $invoice['invoice_type'] == 'wholesale') ? 'block' : 'none'; ?>;">
            <label class="form-label">关联订单</label>
            <div class="form-input">
                <select id="order_id" name="order_id" class="form-control">
                    <option value="">-- 选择订单 --</option>
                    <?php foreach ($orders as $order): ?>
                        <option value="<?php echo $order['order_id']; ?>" data-customer="<?php echo $order['customer_id']; ?>" <?php echo (isset($invoice['order_id']) && $invoice['order_id'] == $order['order_id']) ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($order['order_number']); ?> (<?php echo htmlspecialchars($order['customer_name']); ?>)
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">客户</label>
            <div class="form-input">
                <select id="customer_id" name="customer_id" class="form-control" required>
                    <option value="">-- 请选择客户 --</option>
                    <?php foreach ($customers as $customer): ?>
                        <option value="<?php echo $customer['customer_id']; ?>" <?php echo (isset($invoice['customer_id']) && $invoice['customer_id'] == $customer['customer_id']) ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($customer['customer_name']); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">发票日期</label>
            <div class="form-input">
                <input type="date" name="invoice_date" class="form-control" value="<?php echo isset($invoice['invoice_date']) ? $invoice['invoice_date'] : date('Y-m-d'); ?>" required>
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">备注</label>
            <div class="form-input">
                <textarea id="remark" name="remark" class="form-control" rows="3"><?php echo htmlspecialchars($invoice['remark'] ?? ''); ?></textarea>
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">发票明细</label>
            <div class="form-input">
                <div class="table-responsive">
                    <table class="data-table" id="invoiceItemsTable">
                        <thead>
                            <tr>
                                <th class="warehouse-column">仓库 <span class="required">*</span></th>
                                <th class="product-column">商品 <span class="required">*</span></th>
                                <th class="batch-column">批次 <span class="required">*</span></th>
                                <th class="unit-column">单位</th>
                                <th class="price-column">单价(元) <span class="required">*</span></th>
                                <th class="quantity-column">数量 <span class="required">*</span></th>
                                <th class="discount-column">折扣(%)</th>
                                <th class="subtotal-column">小计(元)</th>
                                <th class="remark-column">备注</th>
                                <th class="action-column">操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (count($invoiceItems) > 0): ?>
                                <?php foreach ($invoiceItems as $index => $item): ?>
                                    <tr>
                                        <td class="warehouse-column">
                                            <select name="items[<?php echo $index; ?>][warehouse_id]" class="form-control warehouse-select" data-value="<?php echo $item['warehouse_id']; ?>" data-row-index="<?php echo $index; ?>" required>
                                                <option value="">请选择仓库</option>
                                                <?php foreach ($warehouses as $warehouse): ?>
                                                    <option value="<?php echo $warehouse['warehouse_id']; ?>" <?php echo $item['warehouse_id'] == $warehouse['warehouse_id'] ? 'selected' : ''; ?>>
                                                        <?php echo htmlspecialchars($warehouse['warehouse_name']); ?>
                                                    </option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                        <td class="product-column">
                                            <div class="product-select-container">
                                                <select name="items[<?php echo $index; ?>][product_id]" class="form-control product-select" data-row-index="<?php echo $index; ?>" required>
                                                    <option value="">请选择商品</option>
                                                    <?php foreach ($products as $product): ?>
                                                        <option value="<?php echo $product['product_id']; ?>"
                                                            data-price="<?php echo $product['unit_price']; ?>"
                                                            data-unit="<?php echo $product['unit']; ?>"
                                                            <?php echo $item['product_id'] == $product['product_id'] ? 'selected' : ''; ?>>
                                                            <?php echo htmlspecialchars($product['product_name']); ?>
                                                        </option>
                                                    <?php endforeach; ?>
                                                </select>
                                            </div>
                                        </td>
                                        <td class="batch-column">
                                            <select name="items[<?php echo $index; ?>][batch_id]" class="form-control batch-select" data-preselected-id="<?php echo $item['batch_id']; ?>" data-row-index="<?php echo $index; ?>" required>
                                                <option value="">请选择批次</option>
                                                <?php if (!empty($item['batches'])): ?>
                                                    <?php foreach ($item['batches'] as $batch): ?>
                                                        <option value="<?php echo $batch['batch_id']; ?>" <?php echo $item['batch_id'] == $batch['batch_id'] ? 'selected' : ''; ?>>
                                                            <?php echo htmlspecialchars($batch['batch_number'] . ' (库存:' . $batch['quantity'] . ')'); ?>
                                                        </option>
                                                    <?php endforeach; ?>
                                                <?php endif; ?>
                                            </select>
                                        </td>
                                        <td class="unit-column">
                                            <input type="text" name="items[<?php echo $index; ?>][unit]" class="form-control product-unit" value="<?php echo htmlspecialchars($item['unit'] ?? ''); ?>" readonly>
                                        </td>
                                        <td class="price-column">
                                            <input type="number" name="items[<?php echo $index; ?>][unit_price]" class="form-control unit-price" value="<?php echo $item['unit_price']; ?>" step="0.01" required>
                                        </td>
                                        <td class="quantity-column">
                                            <input type="number" name="items[<?php echo $index; ?>][quantity]" class="form-control quantity" value="<?php echo $item['quantity']; ?>" min="1" required>
                                        </td>
                                        <td class="discount-column">
                                            <input type="number" name="items[<?php echo $index; ?>][discount_rate]" class="form-control discount-rate" value="<?php echo isset($item['discount_rate']) ? $item['discount_rate'] : 0; ?>" min="0" max="100" step="0.01">
                                        </td>
                                        <td class="subtotal-column">
                                            <input type="text" class="form-control subtotal" value="<?php echo number_format($item['unit_price'] * $item['quantity'] * (1 - ($item['discount_rate'] ?? 0) / 100), 2); ?>" readonly>
                                        </td>
                                        <td class="remark-column">
                                            <input type="text" name="items[<?php echo $index; ?>][remark]" class="form-control" value="<?php echo htmlspecialchars($item['remark'] ?? ''); ?>">
                                        </td>
                                        <td class="action-column">
                                            <button type="button" class="btn btn-sm btn-danger remove-item">删除</button>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td class="warehouse-column">
                                        <select name="items[0][warehouse_id]" class="form-control warehouse-select" required>
                                            <option value="">请选择仓库</option>
                                            <?php foreach ($warehouses as $warehouse): ?>
                                                <option value="<?php echo $warehouse['warehouse_id']; ?>">
                                                    <?php echo htmlspecialchars($warehouse['warehouse_name']); ?>
                                                </option>
                                            <?php endforeach; ?>
                                        </select>
                                    </td>
                                    <td class="product-column">
                                        <div class="product-select-container">
                                            <select name="items[0][product_id]" class="form-control product-select" required>
                                                <option value="">请选择商品</option>
                                                <?php foreach ($products as $product): ?>
                                                    <option value="<?php echo $product['product_id']; ?>"
                                                        data-price="<?php echo $product['unit_price']; ?>"
                                                        data-unit="<?php echo $product['unit']; ?>">
                                                        <?php echo htmlspecialchars($product['product_name']); ?>
                                                    </option>
                                                <?php endforeach; ?>
                                            </select>
                                        </div>
                                    </td>
                                    <td class="batch-column">
                                        <select name="items[0][batch_id]" class="form-control batch-select" required>
                                            <option value="">请先选择仓库和商品</option>
                                        </select>
                                    </td>
                                    <td class="unit-column">
                                        <input type="text" name="items[0][unit]" class="form-control product-unit" readonly>
                                    </td>
                                    <td class="price-column">
                                        <input type="number" name="items[0][unit_price]" class="form-control unit-price" step="0.01" required>
                                    </td>
                                    <td class="quantity-column">
                                        <input type="number" name="items[0][quantity]" class="form-control quantity" min="1" value="1" required>
                                    </td>
                                    <td class="discount-column">
                                        <input type="number" name="items[0][discount_rate]" class="form-control discount-rate" value="0" min="0" max="100" step="0.01">
                                    </td>
                                    <td class="subtotal-column">
                                        <input type="text" class="form-control subtotal" readonly>
                                    </td>
                                    <td class="remark-column">
                                        <input type="text" name="items[0][remark]" class="form-control">
                                    </td>
                                    <td class="action-column">
                                        <button type="button" class="btn btn-sm btn-danger remove-item">删除</button>
                                    </td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                        <tfoot>
                            <tr>
                                <td colspan="7" class="text-right"><strong>总计：</strong></td>
                                <td>
                                    <input type="text" id="totalAmount" name="total_amount" class="form-control" readonly>
                                </td>
                                <td colspan="2">
                                    <button type="button" class="btn btn-sm btn-primary" id="addItem">添加商品</button>
                                </td>
                            </tr>
                        </tfoot>
                    </table>
                </div>
            </div>
        </div>

        <div class="form-actions">
            <button type="submit" class="btn btn-primary">保存</button>
            <a href="index.php?page=invoice" class="btn btn-secondary">取消</a>
        </div>
    </form>
</div>

<script>
    $(document).ready(function() {
        // 设置初始化标志，防止事件处理程序在初始化过程中触发
        window.initializing = true;

        // 初始化Select2
        initializeSelect2();

        // 初始化已有行的商品、仓库和批次
        $('.product-select').each(function(index) {
            var row = $(this).closest('tr');
            var productId = $(this).val();

            // 如果已经选择了商品，确保单位信息已经更新
            var selectedOption = $(this).find('option:selected');
            if (selectedOption.val()) {
                var unit = selectedOption.data('unit');
                row.find('.product-unit').val(unit);
                console.log('初始化商品单位信息:', unit);
            }

            // 确保批次信息已经加载
            var warehouseId = row.find('.warehouse-select').val();
            var batchSelect = row.find('.batch-select');
            var batchId = batchSelect.data('preselected-id'); // 获取预选的批次ID

            if (productId && warehouseId) {
                console.log('初始化批次信息 - 商品ID:', productId, '仓库ID:', warehouseId, '批次ID:', batchId);

                // 立即手动加载批次信息，传入批次ID
                loadBatches(row, batchId);

                // 为所有商品行绑定事件处理函数
                bindEventHandlers(row);
            }
        });

        // 编辑模式下特殊处理，确保仓库和批次下拉列表正确加载和选中
        <?php if ($isEdit && count($invoiceItems) > 0): ?>
            // 采用更直接的方法初始化仓库和批次
            setTimeout(function() {
                console.log('采用新方法初始化仓库和批次选择');

                // 清除所有行的初始化标记以使选择器能够被正确更新
                window.initializing = false;

                <?php foreach ($invoiceItems as $index => $item): ?>
                    console.log('正在处理行 <?php echo $index; ?> - 仓库ID: <?php echo $item['warehouse_id']; ?>, 商品ID: <?php echo $item['product_id']; ?>, 批次ID: <?php echo $item['batch_id']; ?>');

                    // 直接设置仓库 - 确保使用正确的索引
                    var currentRow<?php echo $index; ?> = $('#invoiceItemsTable tbody tr').eq(<?php echo $index; ?>);
                    var warehouseSelect<?php echo $index; ?> = currentRow<?php echo $index; ?>.find('.warehouse-select');

                    // 强制设置仓库ID
                    warehouseSelect<?php echo $index; ?>.val('<?php echo $item['warehouse_id']; ?>');
                    warehouseSelect<?php echo $index; ?>.trigger('change.select2');

                    // 记录每行的仓库选择状态
                    console.log('行 <?php echo $index; ?> 的仓库ID被设置为: <?php echo $item['warehouse_id']; ?>');

                    // 先删除批次下拉框的所有现有选项并添加一个包含当前批次ID的选项
                    var batchSelect<?php echo $index; ?> = currentRow<?php echo $index; ?>.find('.batch-select');
                    batchSelect<?php echo $index; ?>.empty();
                    batchSelect<?php echo $index; ?>.append('<option value="<?php echo $item['batch_id']; ?>">批次ID: <?php echo $item['batch_id']; ?></option>');
                    batchSelect<?php echo $index; ?>.val('<?php echo $item['batch_id']; ?>');
                    batchSelect<?php echo $index; ?>.trigger('change.select2');

                    // 使用AJAX获取完整批次信息
                    $.ajax({
                        url: '../../ajax/get_batches.php',
                        type: 'GET',
                        dataType: 'json',
                        data: {
                            warehouse_id: '<?php echo $item['warehouse_id']; ?>',
                            product_id: '<?php echo $item['product_id']; ?>',
                            batch_id: '<?php echo $item['batch_id']; ?>'
                        },
                        success: function(data) {
                            if (Array.isArray(data) && data.length > 0) {
                                // 保留当前选中的值
                                var currentValue = batchSelect<?php echo $index; ?>.val();

                                // 清空并添加新选项
                                batchSelect<?php echo $index; ?>.empty().append('<option value="">请选择批次</option>');

                                data.forEach(function(batch) {
                                    var option = $('<option></option>')
                                        .val(batch.batch_id)
                                        .text(batch.batch_number + ' (库存:' + batch.quantity + ')');

                                    if (batch.batch_id == currentValue) {
                                        option.prop('selected', true);
                                    }

                                    batchSelect<?php echo $index; ?>.append(option);
                                });

                                // 确保选中值被保留
                                batchSelect<?php echo $index; ?>.val(currentValue).trigger('change.select2');
                            }
                        }
                    });
                <?php endforeach; ?>
            }, 500);
        <?php endif; ?>

        // 初始化Select2函数
        function initializeSelect2() {
            // 为商品选择初始化Select2
            $('.product-select').select2({
                placeholder: '请选择商品',
                allowClear: true,
                width: '100%',
                dropdownParent: $('.product-select-container').first().parent()
            });

            // 为仓库选择初始化Select2
            $('.warehouse-select').select2({
                placeholder: '请选择仓库',
                allowClear: true,
                width: '100%'
            });

            // 为批次选择初始化Select2
            $('.batch-select').select2({
                placeholder: '请选择批次',
                allowClear: true,
                width: '100%'
            });

            // 编辑模式下强制设置所有值（应对Select2有时会覆盖预选值的情况）
            <?php if ($isEdit): ?>
                // 先避免触发事件引起的连锁反应
                setTimeout(function() {
                    console.log('强制设置仓库和批次的初始值');

                    // 强制设置所有商品选择
                    <?php foreach ($invoiceItems as $index => $item): ?>
                        var productSelect<?php echo $index; ?> = $('#invoiceItemsTable tbody tr').eq(<?php echo $index; ?>).find('.product-select');
                        productSelect<?php echo $index; ?>.val('<?php echo $item['product_id']; ?>');
                        productSelect<?php echo $index; ?>.trigger('change.select2');
                        console.log('设置行 <?php echo $index; ?> 的商品ID为: <?php echo $item['product_id']; ?>');
                    <?php endforeach; ?>

                    // 确保每行仓库ID设置独立 - 使用不同的超时确保顺序执行
                    <?php foreach ($invoiceItems as $index => $item): ?>
                        setTimeout(function() {
                            var warehouseSelect<?php echo $index; ?> = $('#invoiceItemsTable tbody tr').eq(<?php echo $index; ?>).find('.warehouse-select');
                            warehouseSelect<?php echo $index; ?>.val('<?php echo $item['warehouse_id']; ?>');
                            warehouseSelect<?php echo $index; ?>.trigger('change.select2');
                            console.log('第二次设置 - 行 <?php echo $index; ?> 的仓库ID为: <?php echo $item['warehouse_id']; ?>');
                        }, <?php echo 150 + $index * 50; ?>);
                    <?php endforeach; ?>
                }, 200);
            <?php endif; ?>
        }

        // 添加新行
        $('#addItem').on('click', function() {
            console.log('添加商品按钮被点击');
            var rowIndex = $('.warehouse-select').length;
            var newRow = `
                <tr>
                    <td class="warehouse-column">
                        <select name="items[${rowIndex}][warehouse_id]" class="form-control warehouse-select" data-row-index="${rowIndex}" required>
                            <option value="">请选择仓库</option>
                            <?php foreach ($warehouses as $warehouse): ?>
                                <option value="<?php echo $warehouse['warehouse_id']; ?>">
                                    <?php echo htmlspecialchars($warehouse['warehouse_name']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </td>
                    <td class="product-column">
                        <div class="product-select-container">
                            <select name="items[${rowIndex}][product_id]" class="form-control product-select" data-row-index="${rowIndex}" required>
                                <option value="">请选择商品</option>
                                <?php foreach ($products as $product): ?>
                                    <option value="<?php echo $product['product_id']; ?>"
                                        data-price="<?php echo $product['unit_price']; ?>"
                                        data-unit="<?php echo $product['unit']; ?>">
                                        <?php echo htmlspecialchars($product['product_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </td>
                    <td class="batch-column">
                        <select name="items[${rowIndex}][batch_id]" class="form-control batch-select" data-row-index="${rowIndex}" required>
                            <option value="">请先选择仓库和商品</option>
                        </select>
                    </td>
                    <td class="unit-column">
                        <input type="text" name="items[${rowIndex}][unit]" class="form-control product-unit" readonly>
                    </td>
                    <td class="price-column">
                        <input type="number" name="items[${rowIndex}][unit_price]" class="form-control unit-price" step="0.01" required>
                    </td>
                    <td class="quantity-column">
                        <input type="number" name="items[${rowIndex}][quantity]" class="form-control quantity" min="1" value="1" required>
                    </td>
                    <td class="discount-column">
                        <input type="number" name="items[${rowIndex}][discount_rate]" class="form-control discount-rate" value="0" min="0" max="100" step="0.01">
                    </td>
                    <td class="subtotal-column">
                        <input type="text" class="form-control subtotal" readonly>
                    </td>
                    <td class="remark-column">
                        <input type="text" name="items[${rowIndex}][remark]" class="form-control">
                    </td>
                    <td class="action-column">
                        <button type="button" class="btn btn-sm btn-danger remove-item">删除</button>
                    </td>
                </tr>
            `;

            $('#invoiceItemsTable tbody').append(newRow);

            // 初始化新行
            var newRow = $('#invoiceItemsTable tbody tr:last');
            console.log('添加了新行，行索引:', rowIndex);

            // 初始化Select2
            newRow.find('.product-select').select2({
                placeholder: '请选择商品',
                allowClear: true,
                width: '100%',
                dropdownParent: newRow.find('.product-select-container').parent()
            });

            newRow.find('.warehouse-select').select2({
                placeholder: '请选择仓库',
                allowClear: true,
                width: '100%'
            });

            newRow.find('.batch-select').select2({
                placeholder: '请选择批次',
                allowClear: true,
                width: '100%'
            });

            // 绑定事件处理器
            bindEventHandlers(newRow);

            // 计算小计
            calculateSubtotal(newRow);
            calculateTotal();
        });

        // 删除行
        $(document).on('click', '.remove-item', function() {
            $(this).closest('tr').remove();
            calculateTotal();
        });

        // 绑定事件处理函数到行
        function bindEventHandlers(row) {
            // 商品选择改变时更新单价和单位
            row.find('.product-select').on('change', function() {
                var rowIndex = row.index();
                console.log('商品选择发生变化 - 行索引:', rowIndex);
                var selectedOption = $(this).find('option:selected');
                var price = selectedOption.data('price') || '';
                var unit = selectedOption.data('unit') || '';

                row.find('.unit-price').val(price);
                row.find('.product-unit').val(unit);

                // 记录当前仓库ID，确保在商品选择变更后不会丢失
                var currentWarehouseId = row.find('.warehouse-select').val();
                console.log('当前行的仓库ID:', currentWarehouseId, '- 行索引:', rowIndex);

                // 编辑模式下，仅在用户手动更改商品时重新加载批次
                if (!window.initializing) {
                    // 获取当前选中的批次ID（如果有）
                    var batchId = row.find('.batch-select').val() || row.find('.batch-select').data('preselected-id');

                    // 确保使用当前行的仓库ID
                    if (currentWarehouseId) {
                        // 重新加载批次前确保仓库ID不变
                        setTimeout(function() {
                            // 再次检查仓库ID是否仍然一致
                            if (row.find('.warehouse-select').val() == currentWarehouseId) {
                                loadBatches(row, batchId);
                            } else {
                                console.log('检测到仓库ID变更，不加载批次 - 行索引:', rowIndex);
                            }
                        }, 50);
                    } else {
                        console.log('缺少仓库ID，需要先选择仓库 - 行索引:', rowIndex);
                    }
                }

                calculateSubtotal(row);
                calculateTotal();
            });

            // 仓库选择改变时加载批次
            row.find('.warehouse-select').on('change', function() {
                var rowIndex = row.index();
                var newWarehouseId = $(this).val();
                console.log('仓库选择发生变化 - 行索引:', rowIndex, '新仓库ID:', newWarehouseId);

                // 编辑模式下，仅在用户手动更改仓库时重新加载批次
                if (!window.initializing) {
                    // 获取当前选中的批次ID（如果有）
                    var batchId = row.find('.batch-select').val() || row.find('.batch-select').data('preselected-id');
                    if (newWarehouseId) {
                        loadBatches(row, batchId);
                    } else {
                        console.log('仓库未选择，不加载批次 - 行索引:', rowIndex);
                        row.find('.batch-select').empty().append('<option value="">请先选择仓库</option>');
                    }
                }
            });

            // 数量、单价或折扣率改变时更新小计
            row.find('.quantity, .unit-price, .discount-rate').on('input', function() {
                calculateSubtotal(row);
                calculateTotal();
            });
        }

        // 批次加载函数
        function loadBatches(row, batchId) {
            var warehouseSelect = row.find('.warehouse-select');
            var productSelect = row.find('.product-select');
            var batchSelect = row.find('.batch-select');

            var warehouseId = warehouseSelect.val();
            var productId = productSelect.val();

            // 记录当前行的状态和请求参数
            var rowIndex = row.index();
            console.log('loadBatches - 行索引:', rowIndex, '仓库ID:', warehouseId, '商品ID:', productId, '批次ID:', batchId);

            if (!warehouseId || !productId) {
                console.log('缺少仓库ID或商品ID，无法加载批次');
                batchSelect.empty().append('<option value="">请选择批次</option>');
                batchSelect.prop('disabled', true);
                return;
            }

            console.log('加载批次 - 行索引:', rowIndex, '仓库:', warehouseId, '商品:', productId, '当前批次:', batchId);
            batchSelect.prop('disabled', true);

            // 发起AJAX请求获取批次数据
            $.ajax({
                url: '../../ajax/get_batches.php',
                type: 'GET',
                dataType: 'json',
                data: {
                    warehouse_id: warehouseId,
                    product_id: productId,
                    batch_id: batchId || ''
                },
                success: function(data) {
                    console.log('获取到批次数据 - 行索引:', rowIndex, '仓库ID:', warehouseId, '数据量:', data ? data.length : 0);

                    // 再次检查行的仓库ID是否已经变更，如果变更则不更新批次
                    var currentWarehouseId = warehouseSelect.val();
                    if (currentWarehouseId != warehouseId) {
                        console.log('仓库ID已变更，不更新批次 - 当前值:', currentWarehouseId, '请求时值:', warehouseId);
                        batchSelect.prop('disabled', false);
                        return;
                    }

                    batchSelect.empty().append('<option value="">请选择批次</option>');

                    if (Array.isArray(data) && data.length > 0) {
                        // 批次数据解析
                        data.forEach(function(batch) {
                            var option = $('<option></option>')
                                .val(batch.batch_id)
                                .text(batch.batch_number + ' (库存:' + batch.quantity + ')');

                            if (batch.batch_id == batchId) {
                                option.prop('selected', true);
                            }

                            batchSelect.append(option);
                        });

                        // 如果有传入的批次ID，设置该批次被选中
                        if (batchId) {
                            batchSelect.val(batchId).trigger('change');
                            console.log('批次已设置为:', batchId, '- 行索引:', rowIndex);
                        }
                    } else if (batchId) {
                        // 如果没有批次数据但有批次ID（编辑模式下可能发生），添加一个选项
                        console.log('未获取到批次数据，添加当前批次ID作为选项');
                        batchSelect.append(
                            $('<option></option>')
                            .val(batchId)
                            .text('批次ID: ' + batchId)
                            .prop('selected', true)
                        );
                    }

                    batchSelect.prop('disabled', false);
                },
                error: function(xhr, status, error) {
                    console.error('加载批次失败 - 行索引:', rowIndex, '仓库ID:', warehouseId, '错误:', status, error);
                    console.log('响应文本:', xhr.responseText);
                    batchSelect.prop('disabled', false);
                }
            });
        }

        // 初始绑定所有行的事件
        $('#invoiceItemsTable tbody tr').each(function() {
            bindEventHandlers($(this));
        });

        // 计算小计
        function calculateSubtotal(row) {
            var quantity = parseFloat(row.find('.quantity').val()) || 0;
            var unitPrice = parseFloat(row.find('.unit-price').val()) || 0;
            var discountRate = parseFloat(row.find('.discount-rate').val()) || 0;

            // 计算折扣后价格
            var discountedPrice = unitPrice * (1 - discountRate / 100);
            var subtotal = quantity * discountedPrice;

            row.find('.subtotal').val(subtotal.toFixed(2));
        }

        // 计算总计
        function calculateTotal() {
            var total = 0;
            $('.subtotal').each(function() {
                total += parseFloat($(this).val()) || 0;
            });
            $('#totalAmount').val(total.toFixed(2));
        }

        // 表单提交前验证
        $('#invoiceForm').on('submit', function(e) {
            try {
                console.log('提交表单...');
                // 检查客户选择
                if (!$('#customer_id').val()) {
                    alert('请选择客户');
                    e.preventDefault();
                    return false;
                }

                // 检查至少有一个商品行
                if ($('#invoiceItemsTable tbody tr').length === 0) {
                    alert('请至少添加一个商品');
                    e.preventDefault();
                    return false;
                }

                // 如果是编辑模式，确保invoice_id存在且值正确
                <?php if ($isEdit): ?>
                    if (!$('input[name="invoice_id"]').val()) {
                        error_log('警告：编辑模式下invoice_id字段为空');
                        $('input[name="invoice_id"]').val('<?php echo $invoiceId; ?>');
                    }
                <?php endif; ?>

                // 验证发票类型
                const invoiceType = $('#invoice_type').val();
                if (!['retail', 'wholesale'].includes(invoiceType)) {
                    console.log('无效的invoice_type，设置为默认值retail');
                    $('#invoice_type').val('retail');
                }

                // 验证发票状态
                const invoiceStatus = $('select[name="invoice_status"]').val();
                if (!['draft', 'issued', 'cancelled'].includes(invoiceStatus)) {
                    console.log('无效的invoice_status，设置为默认值draft');
                    $('select[name="invoice_status"]').val('draft');
                }

                // 验证付款状态
                const paymentStatus = $('select[name="payment_status"]').val();
                if (!['unpaid', 'partial', 'paid'].includes(paymentStatus)) {
                    console.log('无效的payment_status，设置为默认值unpaid');
                    $('select[name="payment_status"]').val('unpaid');
                }

                return true;
            } catch (error) {
                console.error('表单提交验证发生错误:', error);
                alert('表单验证错误: ' + error.message);
                e.preventDefault();
                return false;
            }
        });

        // 显示/隐藏关联订单选择
        function toggleOrderField() {
            const invoiceType = $('#invoice_type').val();
            const orderGroup = $('#order_id_group');

            if (invoiceType === 'wholesale') {
                orderGroup.show();
            } else {
                orderGroup.hide();
                $('#order_id').val('').trigger('change');
            }
        }

        // 初始化调用一次
        toggleOrderField();

        // 发票类型变更时触发
        $('#invoice_type').on('change', toggleOrderField);

        // 选择订单时自动设置客户
        $('#order_id').on('change', function() {
            var selectedOption = $(this).find('option:selected');
            var customerId = selectedOption.data('customer');

            if (customerId) {
                $('#customer_id').val(customerId).trigger('change');
            }
        });

        // 初始化计算
        calculateTotal();

        // 所有初始化完成后，移除初始化标志
        setTimeout(function() {
            window.initializing = false;
            console.log('初始化完成，页面可以正常交互');
        }, 2000);

        // 控制已付金额字段的显示/隐藏
        function togglePaidAmountField() {
            var status = $('#paymentStatus').val();
            if (status === 'partial' || status === 'paid') {
                $('.payment-amount-group').show();
            } else {
                $('.payment-amount-group').hide();
                if (status === 'unpaid') {
                    $('#paidAmount').val(0);
                }
            }
        }

        // 初始化时检查
        togglePaidAmountField();

        // 绑定付款状态变更事件
        $('#paymentStatus').change(function() {
            togglePaidAmountField();
        });
    });
</script>