<?php
// 防止直接访问
defined('IN_SYSTEM') || die('禁止访问');

// 初始化变量以避免未定义错误
$totalRecords = $totalRecords ?? 0;
$invoices = $invoices ?? [];
$totalPages = $totalPages ?? 1;

// 初始化搜索变量
$search = isset($_GET['search']) ? $_GET['search'] : '';
$status = isset($_GET['status']) ? $_GET['status'] : '';
$type = isset($_GET['type']) ? $_GET['type'] : '';
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : '';
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : '';
$page = isset($_GET['listpage']) ? intval($_GET['listpage']) : 1;

// 获取客户列表（用于搜索筛选）
$customerSql = "SELECT customer_id, customer_name FROM customers ORDER BY customer_name";
$customerResult = $conn->query($customerSql);
$customers = [];
while ($customerResult && $row = $customerResult->fetch_assoc()) {
    $customers[] = $row;
}
?>

<!-- 显示消息 -->
<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<div class="module-tools">
    <div class="tool-left">
        <a href="index.php?page=invoice&action=add" class="btn btn-primary">创建销售开单</a>
    </div>
    <div class="tool-right">
        <form action="index.php" method="get" class="search-form">
            <input type="hidden" name="page" value="invoice">
            <div class="search-group">
                <input type="text" name="search" class="search-input" placeholder="搜索发票号或客户" value="<?php echo htmlspecialchars($search); ?>">
            </div>
            <div class="search-group">
                <select name="status" class="search-input">
                    <option value="">所有状态</option>
                    <option value="draft" <?php echo $status == 'draft' ? 'selected' : ''; ?>>草稿</option>
                    <option value="issued" <?php echo $status == 'issued' ? 'selected' : ''; ?>>已开票</option>
                    <option value="cancelled" <?php echo $status == 'cancelled' ? 'selected' : ''; ?>>已取消</option>
                </select>
            </div>
            <div class="search-group">
                <select name="type" class="search-input">
                    <option value="">所有类型</option>
                    <option value="retail" <?php echo $type == 'retail' ? 'selected' : ''; ?>>零售</option>
                    <option value="wholesale" <?php echo $type == 'wholesale' ? 'selected' : ''; ?>>批发</option>
                </select>
            </div>
            <div class="search-group">
                <input type="date" name="start_date" class="search-input date" placeholder="开始日期" value="<?php echo htmlspecialchars($start_date); ?>">
            </div>
            <div class="search-group">
                <input type="date" name="end_date" class="search-input date" placeholder="结束日期" value="<?php echo htmlspecialchars($end_date); ?>">
            </div>
            <button type="submit" class="btn btn-secondary">搜索</button>
            <a href="index.php?page=invoice" class="btn btn-secondary">重置</a>
        </form>
    </div>
</div>

<!-- 销售开单列表 -->
<div class="data-wrapper">
    <h4 class="data-title">销售开单列表 (<?php echo $totalRecords; ?>条记录)</h4>

    <table class="data-table">
        <thead>
            <tr>
                <th>发票编号</th>
                <th>客户</th>
                <th>发票日期</th>
                <th>发票类型</th>
                <th>总金额(元)</th>
                <th>已付金额(元)</th>
                <th>发票状态</th>
                <th>付款状态</th>
                <th>创建时间</th>
                <th>操作</th>
            </tr>
        </thead>
        <tbody>
            <?php if (count($invoices) > 0): ?>
                <?php foreach ($invoices as $invoice): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($invoice['invoice_number']); ?></td>
                        <td><?php echo htmlspecialchars($invoice['customer_name'] ?? '未知客户'); ?></td>
                        <td><?php echo $invoice['invoice_date'] ?? ''; ?></td>
                        <td><?php echo getInvoiceTypeName($invoice['invoice_type'] ?? 'retail'); ?></td>
                        <td class="text-right"><?php echo number_format($invoice['total_amount'] ?? 0, 2); ?></td>
                        <td class="text-right"><?php echo number_format($invoice['paid_amount'] ?? 0, 2); ?></td>
                        <td>
                            <span class="badge badge-<?php echo getInvoiceStatusBadgeClass($invoice['invoice_status'] ?? 'draft'); ?>">
                                <?php echo getInvoiceStatusName($invoice['invoice_status'] ?? 'draft'); ?>
                            </span>
                        </td>
                        <td>
                            <span class="badge badge-<?php echo getPaymentStatusBadgeClass($invoice['payment_status'] ?? 'unpaid'); ?>">
                                <?php echo getPaymentStatusName($invoice['payment_status'] ?? 'unpaid'); ?>
                            </span>
                        </td>
                        <td><?php echo $invoice['created_at'] ?? ''; ?></td>
                        <td>
                            <a href="index.php?page=invoice&action=view&id=<?php echo $invoice['invoice_id']; ?>" class="btn btn-sm btn-info">查看</a>
                            <?php if (($invoice['invoice_status'] ?? 'draft') == 'draft'): ?>
                                <a href="index.php?page=invoice&action=edit&id=<?php echo $invoice['invoice_id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                                <a href="javascript:void(0);" onclick="confirmDelete(<?php echo $invoice['invoice_id']; ?>, '<?php echo htmlspecialchars($invoice['invoice_number']); ?>')" class="btn btn-sm btn-danger">删除</a>
                            <?php endif; ?>
                        </td>
                    </tr>
                <?php endforeach; ?>
            <?php else: ?>
                <tr>
                    <td colspan="10" class="text-center">暂无销售开单数据</td>
                </tr>
            <?php endif; ?>
        </tbody>
    </table>

    <!-- 分页控件 -->
    <?php if ($totalPages > 1): ?>
        <div class="pagination">
            <?php if ($page > 1): ?>
                <a href="index.php?page=invoice&listpage=1&search=<?php echo urlencode($search); ?>&status=<?php echo urlencode($status); ?>&type=<?php echo urlencode($type); ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>" class="pagination-item">首页</a>
                <a href="index.php?page=invoice&listpage=<?php echo $page - 1; ?>&search=<?php echo urlencode($search); ?>&status=<?php echo urlencode($status); ?>&type=<?php echo urlencode($type); ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>" class="pagination-item">上一页</a>
            <?php endif; ?>

            <?php
            $startPage = max(1, $page - 2);
            $endPage = min($totalPages, $page + 2);

            for ($i = $startPage; $i <= $endPage; $i++):
            ?>
                <a href="index.php?page=invoice&listpage=<?php echo $i; ?>&search=<?php echo urlencode($search); ?>&status=<?php echo urlencode($status); ?>&type=<?php echo urlencode($type); ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>" class="pagination-item <?php echo $i == $page ? 'active' : ''; ?>"><?php echo $i; ?></a>
            <?php endfor; ?>

            <?php if ($page < $totalPages): ?>
                <a href="index.php?page=invoice&listpage=<?php echo $page + 1; ?>&search=<?php echo urlencode($search); ?>&status=<?php echo urlencode($status); ?>&type=<?php echo urlencode($type); ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>" class="pagination-item">下一页</a>
                <a href="index.php?page=invoice&listpage=<?php echo $totalPages; ?>&search=<?php echo urlencode($search); ?>&status=<?php echo urlencode($status); ?>&type=<?php echo urlencode($type); ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>" class="pagination-item">末页</a>
            <?php endif; ?>
        </div>
    <?php endif; ?>
</div>

<script>
    // 删除发票确认
    function confirmDelete(invoiceId, invoiceNumber) {
        if (confirm('确定要删除销售开单 ' + invoiceNumber + ' 吗？此操作不可恢复！')) {
            window.location.href = 'index.php?page=invoice&action=delete&id=' + invoiceId;
        }
    }
</script>