<?php
// 防止直接访问
defined('IN_SYSTEM') || die('禁止访问');

// 调试信息
error_log("Action: " . $action);
// error_log("Order Data: " . print_r($order, true));
// error_log("Order Items: " . print_r($orderItems, true));

// 获取客户列表
$customerSql = "SELECT customer_id, customer_name FROM customers ORDER BY customer_name";
$customerResult = $conn->query($customerSql);
$customers = [];
while ($customerResult && $row = $customerResult->fetch_assoc()) {
    $customers[] = $row;
}

// 获取商品列表 - 包含单位信息
$productSql = "SELECT product_id, product_name, unit_price, unit FROM products ORDER BY product_name";
$productResult = $conn->query($productSql);
$products = [];
while ($productResult && $row = $productResult->fetch_assoc()) {
    $products[] = $row;
}

// 如果是编辑模式，获取订单数据
$order = [];
$orderItems = [];
if ($action === 'edit' && isset($_GET['id'])) {
    $order_id = $_GET['id'];
    error_log("编辑模式 - Order ID: " . $order_id);

    $orderSql = "SELECT * FROM sales_orders WHERE order_id = ?";
    $stmt = $conn->prepare($orderSql);
    $stmt->bind_param("i", $order_id);
    $stmt->execute();
    $result = $stmt->get_result();
    if ($result && $row = $result->fetch_assoc()) {
        $order = $row;
        error_log("获取到订单数据: " . print_r($order, true));

        // 获取订单明细
        $itemsSql = "SELECT soi.*, p.product_name, p.unit 
                    FROM sales_order_items soi 
                    LEFT JOIN products p ON soi.product_id = p.product_id 
                    WHERE soi.order_id = ?";
        $stmt = $conn->prepare($itemsSql);
        $stmt->bind_param("i", $order_id);
        $stmt->execute();
        $result = $stmt->get_result();
        while ($row = $result->fetch_assoc()) {
            $orderItems[] = $row;
        }
        error_log("获取到订单明细: " . print_r($orderItems, true));
    } else {
        error_log("未找到订单数据");
    }
}
?>

<!-- 加载CSS和JS -->
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
<script src="https://cdn.jsdelivr.net/npm/jquery@3.6.0/dist/jquery.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>

<style>
    /* 自定义样式，调整商品选择宽度 */
    .product-select-container {
        min-width: 300px;
        width: 100%;
    }

    .select2-container {
        width: 100% !important;
    }

    .product-column {
        min-width: 300px;
        width: 35%;
    }

    .unit-column,
    .price-column,
    .quantity-column,
    .discount-column {
        width: 12%;
    }

    .subtotal-column {
        width: 14%;
    }

    .action-column {
        width: 10%;
    }
</style>

<!-- 显示消息 -->
<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<div class="module-tools">
    <div class="tool-left">
        <a href="index.php?page=order" class="btn btn-secondary">返回列表</a>
    </div>
</div>

<div class="data-wrapper">
    <h4 class="data-title"><?php echo $action === 'add' ? '创建销售订单' : '编辑销售订单'; ?></h4>

    <form action="index.php?page=order" method="post" class="form-horizontal" id="orderForm">
        <input type="hidden" name="page" value="order">
        <input type="hidden" name="action" value="<?php echo $action; ?>">
        <?php if ($action === 'edit'): ?>
            <input type="hidden" name="order_id" value="<?php echo isset($order['order_id']) ? $order['order_id'] : ''; ?>">
        <?php endif; ?>

        <div class="form-group">
            <label class="form-label">客户</label>
            <div class="form-input">
                <select name="customer_id" class="form-control" required>
                    <option value="">请选择客户</option>
                    <?php foreach ($customers as $customer): ?>
                        <option value="<?php echo $customer['customer_id']; ?>" <?php echo isset($order['customer_id']) && $order['customer_id'] == $customer['customer_id'] ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($customer['customer_name']); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">订单日期</label>
            <div class="form-input">
                <input type="date" name="order_date" class="form-control" value="<?php echo isset($order['order_date']) ? $order['order_date'] : date('Y-m-d'); ?>" required>
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">预计交付日期</label>
            <div class="form-input">
                <input type="date" name="delivery_date" class="form-control" value="<?php echo isset($order['delivery_date']) ? $order['delivery_date'] : ''; ?>">
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">订单状态</label>
            <div class="form-input">
                <select name="order_status" class="form-control" required>
                    <option value="pending" <?php echo isset($order['order_status']) && $order['order_status'] == 'pending' ? 'selected' : ''; ?>>待处理</option>
                    <option value="approved" <?php echo isset($order['order_status']) && $order['order_status'] == 'approved' ? 'selected' : ''; ?>>已审核</option>
                    <option value="shipping" <?php echo isset($order['order_status']) && $order['order_status'] == 'shipping' ? 'selected' : ''; ?>>发货中</option>
                    <option value="completed" <?php echo isset($order['order_status']) && $order['order_status'] == 'completed' ? 'selected' : ''; ?>>已完成</option>
                    <option value="cancelled" <?php echo isset($order['order_status']) && $order['order_status'] == 'cancelled' ? 'selected' : ''; ?>>已取消</option>
                </select>
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">支付状态</label>
            <div class="form-input">
                <select name="payment_status" class="form-control" required>
                    <option value="unpaid" <?php echo isset($order['payment_status']) && $order['payment_status'] == 'unpaid' ? 'selected' : ''; ?>>未支付</option>
                    <option value="partial" <?php echo isset($order['payment_status']) && $order['payment_status'] == 'partial' ? 'selected' : ''; ?>>部分支付</option>
                    <option value="paid" <?php echo isset($order['payment_status']) && $order['payment_status'] == 'paid' ? 'selected' : ''; ?>>已支付</option>
                </select>
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">备注</label>
            <div class="form-input">
                <textarea name="remark" class="form-control" rows="3"><?php echo isset($order['remark']) ? htmlspecialchars($order['remark']) : ''; ?></textarea>
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">订单明细</label>
            <div class="form-input">
                <div class="table-responsive">
                    <table class="data-table" id="orderItemsTable">
                        <thead>
                            <tr>
                                <th class="product-column">商品</th>
                                <th class="unit-column">单位</th>
                                <th class="price-column">单价(元)</th>
                                <th class="quantity-column">数量</th>
                                <th class="discount-column">折扣(%)</th>
                                <th class="subtotal-column">小计(元)</th>
                                <th class="action-column">操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (count($orderItems) > 0): ?>
                                <?php foreach ($orderItems as $index => $item): ?>
                                    <tr>
                                        <td class="product-column">
                                            <div class="product-select-container">
                                                <select name="product_id[]" class="form-control product-select" required>
                                                    <option value="">请选择商品</option>
                                                    <?php foreach ($products as $product): ?>
                                                        <option value="<?php echo $product['product_id']; ?>"
                                                            data-price="<?php echo $product['unit_price']; ?>"
                                                            data-unit="<?php echo $product['unit']; ?>"
                                                            <?php echo $item['product_id'] == $product['product_id'] ? 'selected' : ''; ?>>
                                                            <?php echo htmlspecialchars($product['product_name']); ?>
                                                        </option>
                                                    <?php endforeach; ?>
                                                </select>
                                            </div>
                                        </td>
                                        <td class="unit-column">
                                            <input type="text" name="unit[]" class="form-control product-unit" value="<?php echo htmlspecialchars($item['unit'] ?? ''); ?>" readonly>
                                        </td>
                                        <td class="price-column">
                                            <input type="number" name="unit_price[]" class="form-control unit-price" value="<?php echo $item['unit_price']; ?>" step="0.01" required>
                                        </td>
                                        <td class="quantity-column">
                                            <input type="number" name="quantity[]" class="form-control quantity" value="<?php echo $item['quantity']; ?>" min="1" required>
                                        </td>
                                        <td class="discount-column">
                                            <input type="number" name="discount_rate[]" class="form-control discount-rate" value="<?php echo isset($item['discount_rate']) ? $item['discount_rate'] : 0; ?>" min="0" max="100" step="0.01">
                                        </td>
                                        <td class="subtotal-column">
                                            <input type="text" class="form-control subtotal" value="<?php echo number_format($item['unit_price'] * $item['quantity'] * (1 - ($item['discount_rate'] ?? 0) / 100), 2); ?>" readonly>
                                        </td>
                                        <td class="action-column">
                                            <button type="button" class="btn btn-sm btn-danger remove-item">删除</button>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td class="product-column">
                                        <div class="product-select-container">
                                            <select name="product_id[]" class="form-control product-select" required>
                                                <option value="">请选择商品</option>
                                                <?php foreach ($products as $product): ?>
                                                    <option value="<?php echo $product['product_id']; ?>"
                                                        data-price="<?php echo $product['unit_price']; ?>"
                                                        data-unit="<?php echo $product['unit']; ?>">
                                                        <?php echo htmlspecialchars($product['product_name']); ?>
                                                    </option>
                                                <?php endforeach; ?>
                                            </select>
                                        </div>
                                    </td>
                                    <td class="unit-column">
                                        <input type="text" name="unit[]" class="form-control product-unit" readonly>
                                    </td>
                                    <td class="price-column">
                                        <input type="number" name="unit_price[]" class="form-control unit-price" step="0.01" required>
                                    </td>
                                    <td class="quantity-column">
                                        <input type="number" name="quantity[]" class="form-control quantity" min="1" value="1" required>
                                    </td>
                                    <td class="discount-column">
                                        <input type="number" name="discount_rate[]" class="form-control discount-rate" value="0" min="0" max="100" step="0.01">
                                    </td>
                                    <td class="subtotal-column">
                                        <input type="text" class="form-control subtotal" readonly>
                                    </td>
                                    <td class="action-column">
                                        <button type="button" class="btn btn-sm btn-danger remove-item">删除</button>
                                    </td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                        <tfoot>
                            <tr>
                                <td colspan="5" class="text-right"><strong>总计：</strong></td>
                                <td>
                                    <input type="text" id="totalAmount" name="total_amount" class="form-control" readonly>
                                </td>
                                <td>
                                    <button type="button" class="btn btn-sm btn-primary" id="addItem">添加商品</button>
                                </td>
                            </tr>
                        </tfoot>
                    </table>
                </div>
            </div>
        </div>

        <div class="form-group">
            <div class="form-input">
                <button type="submit" class="btn btn-primary">保存</button>
                <a href="index.php?page=order" class="btn btn-secondary">取消</a>
            </div>
        </div>
    </form>
</div>

<script>
    $(document).ready(function() {
        // 初始化Select2
        initializeSelect2();

        // 初始化已有行的数据
        $('.product-select').each(function() {
            // 如果已经选择了商品，确保单位信息已经更新
            var selectedOption = $(this).find('option:selected');
            if (selectedOption.val()) {
                var unit = selectedOption.data('unit');
                $(this).closest('tr').find('.product-unit').val(unit);
            }
        });

        // 初始化Select2函数
        function initializeSelect2() {
            $('.product-select').select2({
                placeholder: '请选择商品',
                allowClear: true,
                width: '100%',
                dropdownParent: $('.product-select-container')
            });
        }

        // 添加新行
        $('#addItem').on('click', function() {
            console.log('添加商品按钮被点击');
            var newRow = `
        <tr>
            <td class="product-column">
                <div class="product-select-container">
                    <select name="product_id[]" class="form-control product-select" required>
                        <option value="">请选择商品</option>
                        <?php foreach ($products as $product): ?>
                            <option value="<?php echo $product['product_id']; ?>" 
                                    data-price="<?php echo $product['unit_price']; ?>" 
                                    data-unit="<?php echo $product['unit']; ?>">
                                <?php echo htmlspecialchars($product['product_name']); ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
            </td>
            <td class="unit-column">
                <input type="text" name="unit[]" class="form-control product-unit" readonly>
            </td>
            <td class="price-column">
                <input type="number" name="unit_price[]" class="form-control unit-price" step="0.01" required>
            </td>
            <td class="quantity-column">
                <input type="number" name="quantity[]" class="form-control quantity" min="1" value="1" required>
            </td>
            <td class="discount-column">
                <input type="number" name="discount_rate[]" class="form-control discount-rate" value="0" min="0" max="100" step="0.01">
            </td>
            <td class="subtotal-column">
                <input type="text" class="form-control subtotal" readonly>
            </td>
            <td class="action-column">
                <button type="button" class="btn btn-sm btn-danger remove-item">删除</button>
            </td>
        </tr>
        `;

            $('#orderItemsTable tbody').append(newRow);

            // 初始化新行的Select2
            var newSelect = $('#orderItemsTable tbody tr:last .product-select');
            newSelect.select2({
                placeholder: '请选择商品',
                allowClear: true,
                width: '100%',
                dropdownParent: newSelect.closest('.product-select-container')
            });

            // 确保事件绑定到新行
            bindEventHandlers(newSelect.closest('tr'));
        });

        // 删除行
        $(document).on('click', '.remove-item', function() {
            $(this).closest('tr').remove();
            calculateTotal();
        });

        // 绑定事件处理函数到行
        function bindEventHandlers(row) {
            // 商品选择改变时更新单价和单位
            row.find('.product-select').on('change', function() {
                console.log('商品选择发生变化');
                var selectedOption = $(this).find('option:selected');
                var price = selectedOption.data('price') || '';
                var unit = selectedOption.data('unit') || '';

                var row = $(this).closest('tr');
                row.find('.unit-price').val(price);
                row.find('.product-unit').val(unit);

                calculateSubtotal(row);
                calculateTotal();
            });

            // 数量、单价或折扣率改变时更新小计
            row.find('.quantity, .unit-price, .discount-rate').on('input', function() {
                calculateSubtotal(row);
                calculateTotal();
            });
        }

        // 初始绑定所有行的事件
        $('#orderItemsTable tbody tr').each(function() {
            bindEventHandlers($(this));
        });

        // 计算小计
        function calculateSubtotal(row) {
            var quantity = parseFloat(row.find('.quantity').val()) || 0;
            var unitPrice = parseFloat(row.find('.unit-price').val()) || 0;
            var discountRate = parseFloat(row.find('.discount-rate').val()) || 0;

            // 计算折扣后价格
            var discountedPrice = unitPrice * (1 - discountRate / 100);
            var subtotal = quantity * discountedPrice;

            row.find('.subtotal').val(subtotal.toFixed(2));
        }

        // 计算总计
        function calculateTotal() {
            var total = 0;
            $('.subtotal').each(function() {
                total += parseFloat($(this).val()) || 0;
            });
            $('#totalAmount').val(total.toFixed(2));
        }

        // 表单提交前验证
        $('#orderForm').on('submit', function(e) {
            // 检查是否至少有一个商品
            if ($('.product-select').length === 0 || $('.product-select').first().val() === '') {
                alert('请至少添加一个商品');
                e.preventDefault();
                return false;
            }

            // 检查所有必填字段
            var isValid = true;
            $(this).find('[required]').each(function() {
                if (!$(this).val()) {
                    isValid = false;
                    $(this).addClass('is-invalid');
                } else {
                    $(this).removeClass('is-invalid');
                }
            });

            if (!isValid) {
                alert('请填写所有必填字段');
                e.preventDefault();
                return false;
            }

            return true;
        });

        // 初始化计算
        calculateTotal();
    });
</script>