<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 处理清空日志操作
$message = '';
$messageType = '';

// 移除管理员限制，允许所有已登录用户清空日志
if (isset($_GET['action']) && $_GET['action'] == 'clear') {
    try {
        $sql = "TRUNCATE TABLE operation_logs";
        if ($conn->query($sql)) {
            // 记录清空日志的操作
            $operationDetails = "用户 {$_SESSION['username']} 清空了操作日志";
            log_operation($_SESSION['user_id'], '清空日志', $operationDetails);

            $message = '操作日志已清空';
            $messageType = 'success';
        } else {
            $message = '清空日志失败: ' . $conn->error;
            $messageType = 'error';
        }
    } catch (Exception $e) {
        $message = '系统错误: ' . $e->getMessage();
        $messageType = 'error';
    }
}

// 获取分页参数
$page = isset($_GET['p']) ? max(1, intval($_GET['p'])) : 1;
$limit = 20; // 每页显示20条记录
$offset = ($page - 1) * $limit;

// 搜索参数
$searchUser = isset($_GET['user']) ? intval($_GET['user']) : 0;
$searchType = isset($_GET['type']) ? sanitize($_GET['type']) : '';
$searchKeyword = isset($_GET['keyword']) ? sanitize($_GET['keyword']) : '';
$searchDateFrom = isset($_GET['date_from']) ? sanitize($_GET['date_from']) : '';
$searchDateTo = isset($_GET['date_to']) ? sanitize($_GET['date_to']) : '';

// 构建WHERE子句
$whereClause = [];
$params = [];
$types = '';

if ($searchUser > 0) {
    $whereClause[] = "l.user_id = ?";
    $params[] = $searchUser;
    $types .= 'i';
}

if (!empty($searchType)) {
    $whereClause[] = "l.operation_type = ?";
    $params[] = $searchType;
    $types .= 's';
}

if (!empty($searchKeyword)) {
    $whereClause[] = "l.operation_details LIKE ?";
    $params[] = "%$searchKeyword%";
    $types .= 's';
}

if (!empty($searchDateFrom)) {
    $whereClause[] = "DATE(l.operation_time) >= ?";
    $params[] = $searchDateFrom;
    $types .= 's';
}

if (!empty($searchDateTo)) {
    $whereClause[] = "DATE(l.operation_time) <= ?";
    $params[] = $searchDateTo;
    $types .= 's';
}

// 组合WHERE子句
$whereStr = '';
if (!empty($whereClause)) {
    $whereStr = "WHERE " . implode(" AND ", $whereClause);
}

// 查询总记录数
$countSql = "SELECT COUNT(*) as total FROM operation_logs l $whereStr";
$total = 0;

if (!empty($params)) {
    $countStmt = $conn->prepare($countSql);
    if ($countStmt) {
        $countStmt->bind_param($types, ...$params);
        $countStmt->execute();
        $countResult = $countStmt->get_result();
        if ($countRow = $countResult->fetch_assoc()) {
            $total = $countRow['total'];
        }
        $countStmt->close();
    }
} else {
    $countResult = $conn->query($countSql);
    if ($countRow = $countResult->fetch_assoc()) {
        $total = $countRow['total'];
    }
}

// 总页数
$totalPages = ceil($total / $limit);

// 查询日志记录
$logs = [];
$sql = "SELECT l.log_id, l.user_id, u.username, l.operation_type, l.operation_details, l.operation_time 
        FROM operation_logs l 
        LEFT JOIN users u ON l.user_id = u.user_id 
        $whereStr 
        ORDER BY l.operation_time DESC 
        LIMIT ?, ?";

$stmt = $conn->prepare($sql);
if ($stmt) {
    if (!empty($params)) {
        $params[] = $offset;
        $params[] = $limit;
        $types .= 'ii';
        $stmt->bind_param($types, ...$params);
    } else {
        $stmt->bind_param("ii", $offset, $limit);
    }

    $stmt->execute();
    $result = $stmt->get_result();
    while ($row = $result->fetch_assoc()) {
        $logs[] = $row;
    }
    $stmt->close();
}

// 获取所有用户信息用于搜索下拉列表
$users = [];
$userSql = "SELECT user_id, username FROM users ORDER BY username";
$userResult = $conn->query($userSql);
if ($userResult) {
    while ($row = $userResult->fetch_assoc()) {
        $users[] = $row;
    }
}

// 获取所有操作类型用于搜索下拉列表
$operationTypes = [];
$typeSql = "SELECT DISTINCT operation_type FROM operation_logs ORDER BY operation_type";
$typeResult = $conn->query($typeSql);
if ($typeResult) {
    while ($row = $typeResult->fetch_assoc()) {
        $operationTypes[] = $row['operation_type'];
    }
}
?>

<!-- 显示消息 -->
<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<!-- 搜索工具栏 -->
<div class="module-tools">
    <div class="tool-left">
        <a href="index.php?page=log&action=clear" class="btn btn-danger" onclick="return confirm('确定要清空所有操作日志吗？此操作不可恢复！')">清空日志</a>
    </div>
    <div class="tool-right">
        <form action="" method="get" class="search-form">
            <input type="hidden" name="page" value="log">

            <div class="search-group">
                <select name="user">
                    <option value="">-- 所有用户 --</option>
                    <?php foreach ($users as $user): ?>
                        <option value="<?php echo $user['user_id']; ?>" <?php echo $searchUser == $user['user_id'] ? 'selected' : ''; ?>>
                            <?php echo $user['username']; ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="search-group">
                <select name="type">
                    <option value="">-- 所有操作类型 --</option>
                    <?php foreach ($operationTypes as $type): ?>
                        <option value="<?php echo $type; ?>" <?php echo $searchType == $type ? 'selected' : ''; ?>>
                            <?php echo $type; ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="search-group">
                <input type="text" name="keyword" placeholder="操作详情关键词" value="<?php echo $searchKeyword; ?>" class="search-input">
            </div>

            <div class="search-group">
                <input type="date" name="date_from" value="<?php echo $searchDateFrom; ?>" class="search-input date">
                <span>至</span>
                <input type="date" name="date_to" value="<?php echo $searchDateTo; ?>" class="search-input date">
            </div>

            <button type="submit" class="btn btn-secondary">搜索</button>
            <a href="index.php?page=log" class="btn btn-secondary">重置</a>
        </form>
    </div>
</div>

<!-- 日志列表 -->
<div class="data-wrapper">
    <table class="data-table">
        <thead>
            <tr>
                <th>ID</th>
                <th>用户</th>
                <th>操作类型</th>
                <th>操作详情</th>
                <th>操作时间</th>
            </tr>
        </thead>
        <tbody>
            <?php if (count($logs) > 0): ?>
                <?php foreach ($logs as $log): ?>
                    <tr>
                        <td><?php echo $log['log_id']; ?></td>
                        <td><?php echo $log['username'] ? $log['username'] : '用户ID: ' . $log['user_id']; ?></td>
                        <td><?php echo $log['operation_type']; ?></td>
                        <td><?php echo $log['operation_details']; ?></td>
                        <td><?php echo $log['operation_time']; ?></td>
                    </tr>
                <?php endforeach; ?>
            <?php else: ?>
                <tr>
                    <td colspan="5" class="text-center">暂无操作日志</td>
                </tr>
            <?php endif; ?>
        </tbody>
    </table>
</div>

<!-- 分页 -->
<?php if ($totalPages > 1): ?>
    <div class="pagination">
        <?php if ($page > 1): ?>
            <a href="index.php?page=log&p=1<?php echo (!empty($searchUser) ? '&user=' . $searchUser : '') . (!empty($searchType) ? '&type=' . $searchType : '') . (!empty($searchKeyword) ? '&keyword=' . $searchKeyword : '') . (!empty($searchDateFrom) ? '&date_from=' . $searchDateFrom : '') . (!empty($searchDateTo) ? '&date_to=' . $searchDateTo : ''); ?>" class="pagination-item">首页</a>
            <a href="index.php?page=log&p=<?php echo ($page - 1); ?><?php echo (!empty($searchUser) ? '&user=' . $searchUser : '') . (!empty($searchType) ? '&type=' . $searchType : '') . (!empty($searchKeyword) ? '&keyword=' . $searchKeyword : '') . (!empty($searchDateFrom) ? '&date_from=' . $searchDateFrom : '') . (!empty($searchDateTo) ? '&date_to=' . $searchDateTo : ''); ?>" class="pagination-item">上一页</a>
        <?php endif; ?>

        <?php
        $startPage = max(1, $page - 2);
        $endPage = min($totalPages, $page + 2);
        for ($i = $startPage; $i <= $endPage; $i++):
        ?>
            <?php if ($i == $page): ?>
                <span class="pagination-item active"><?php echo $i; ?></span>
            <?php else: ?>
                <a href="index.php?page=log&p=<?php echo $i; ?><?php echo (!empty($searchUser) ? '&user=' . $searchUser : '') . (!empty($searchType) ? '&type=' . $searchType : '') . (!empty($searchKeyword) ? '&keyword=' . $searchKeyword : '') . (!empty($searchDateFrom) ? '&date_from=' . $searchDateFrom : '') . (!empty($searchDateTo) ? '&date_to=' . $searchDateTo : ''); ?>" class="pagination-item"><?php echo $i; ?></a>
            <?php endif; ?>
        <?php endfor; ?>

        <?php if ($page < $totalPages): ?>
            <a href="index.php?page=log&p=<?php echo ($page + 1); ?><?php echo (!empty($searchUser) ? '&user=' . $searchUser : '') . (!empty($searchType) ? '&type=' . $searchType : '') . (!empty($searchKeyword) ? '&keyword=' . $searchKeyword : '') . (!empty($searchDateFrom) ? '&date_from=' . $searchDateFrom : '') . (!empty($searchDateTo) ? '&date_to=' . $searchDateTo : ''); ?>" class="pagination-item">下一页</a>
            <a href="index.php?page=log&p=<?php echo $totalPages; ?><?php echo (!empty($searchUser) ? '&user=' . $searchUser : '') . (!empty($searchType) ? '&type=' . $searchType : '') . (!empty($searchKeyword) ? '&keyword=' . $searchKeyword : '') . (!empty($searchDateFrom) ? '&date_from=' . $searchDateFrom : '') . (!empty($searchDateTo) ? '&date_to=' . $searchDateTo : ''); ?>" class="pagination-item">末页</a>
        <?php endif; ?>
    </div>
<?php endif; ?>

<style>
    /* 确保搜索框和操作按钮的样式正确 */
    .search-form {
        display: flex;
        align-items: center;
        flex-wrap: wrap;
    }

    .search-group {
        margin-right: 10px;
        margin-bottom: 5px;
    }

    .search-input {
        padding: 5px;
        border: 1px solid #ddd;
        border-radius: 3px;
    }

    .search-input.date {
        width: 120px;
    }

    .text-center {
        text-align: center;
    }
</style>